@@ -24,12 +24,28 @@
 
 #include "browser.h"
 #include "cddb_dialog.h"
+#include "charset.h"
 #include "easytag.h"
 #include "file_area.h"
 #include "file_list.h"
+#ifdef ENABLE_FLAC
+#include "flac_header.h"
+#endif
 #include "load_files_dialog.h"
 #include "log.h"
 #include "misc.h"
+#ifdef ENABLE_MP4
+#include "mp4_header.h"
+#endif
+#include "mpeg_header.h"
+#include "monkeyaudio_header.h"
+#include "musepack_header.h"
+#ifdef ENABLE_OGG
+#include "ogg_header.h"
+#endif
+#ifdef ENABLE_OPUS
+#include "opus_header.h"
+#endif
 #include "picture.h"
 #include "playlist_dialog.h"
 #include "preferences_dialog.h"
@@ -40,6 +56,9 @@
 #include "setting.h"
 #include "status_bar.h"
 #include "tag_area.h"
+#ifdef ENABLE_WAVPACK
+#include "wavpack_header.h"
+#endif
 
 /* TODO: Use G_DEFINE_TYPE_WITH_PRIVATE. */
 G_DEFINE_TYPE (EtApplicationWindow, et_application_window, GTK_TYPE_APPLICATION_WINDOW)
@@ -428,8 +447,7 @@ on_invert_selection (GSimpleAction *action,
 
     priv = et_application_window_get_instance_private (self);
 
-    /* Save the current displayed data */
-    ET_Save_File_Data_From_UI (ETCore->ETFileDisplayed);
+    et_application_window_update_et_file_from_ui (self);
 
     et_browser_invert_selection (ET_BROWSER (priv->browser));
     et_application_window_update_actions (self);
@@ -462,8 +480,7 @@ on_delete (GSimpleAction *action,
     self = ET_APPLICATION_WINDOW (user_data);
     priv = et_application_window_get_instance_private (self);
 
-    /* Save the current displayed data */
-    ET_Save_File_Data_From_UI(ETCore->ETFileDisplayed);
+    et_application_window_update_et_file_from_ui (self);
 
     /* Number of files to save */
     selection = et_application_window_browser_get_selection (self);
@@ -505,7 +522,7 @@ on_delete (GSimpleAction *action,
                                                    path);
         gtk_tree_path_free (path);
 
-        ET_Display_File_Data_To_UI(ETFile);
+        et_application_window_display_et_file (self, ETFile);
         et_application_window_browser_select_file_by_et_file (self, ETFile,
                                                               FALSE);
         fraction = (++progress_bar_index) / (double) nb_files_to_delete;
@@ -568,7 +585,9 @@ on_delete (GSimpleAction *action,
 
     /* It's important to displayed the new item, as it'll check the changes in et_browser_toggle_display_mode. */
     if (ETCore->ETFileDisplayed)
-        ET_Display_File_Data_To_UI(ETCore->ETFileDisplayed);
+    {
+        et_application_window_display_et_file (self, ETCore->ETFileDisplayed);
+    }
     /*else if (ET_Displayed_File_List_Current())
         ET_Display_File_Data_To_UI((ET_File *)ET_Displayed_File_List_Current()->data);*/
 
@@ -610,8 +629,7 @@ on_undo_file_changes (GSimpleAction *action,
     self = ET_APPLICATION_WINDOW (user_data);
     priv = et_application_window_get_instance_private (self);
 
-    /* Save the current displayed data */
-    ET_Save_File_Data_From_UI(ETCore->ETFileDisplayed);
+    et_application_window_update_et_file_from_ui (self);
 
     selection = et_application_window_browser_get_selection (self);
     selfilelist = gtk_tree_selection_get_selected_rows(selection, NULL);
@@ -629,7 +647,7 @@ on_undo_file_changes (GSimpleAction *action,
     et_application_window_browser_refresh_list (self);
 
     /* Display the current file */
-    ET_Display_File_Data_To_UI(ETCore->ETFileDisplayed);
+    et_application_window_display_et_file (self, ETCore->ETFileDisplayed);
     et_application_window_update_actions (self);
 
     //ET_Debug_Print_File_List(ETCore->ETFileList,__FILE__,__LINE__,__FUNCTION__);
@@ -653,8 +671,7 @@ on_redo_file_changes (GSimpleAction *action,
     self = ET_APPLICATION_WINDOW (user_data);
     priv = et_application_window_get_instance_private (self);
 
-    /* Save the current displayed data */
-    ET_Save_File_Data_From_UI(ETCore->ETFileDisplayed);
+    et_application_window_update_et_file_from_ui (self);
 
     selection = et_application_window_browser_get_selection (ET_APPLICATION_WINDOW (user_data));
     selfilelist = gtk_tree_selection_get_selected_rows(selection, NULL);
@@ -672,7 +689,7 @@ on_redo_file_changes (GSimpleAction *action,
     et_application_window_browser_refresh_list (ET_APPLICATION_WINDOW (user_data));
 
     /* Display the current file */
-    ET_Display_File_Data_To_UI(ETCore->ETFileDisplayed);
+    et_application_window_display_et_file (self, ETCore->ETFileDisplayed);
     et_application_window_update_actions (self);
 }
 
@@ -738,8 +755,7 @@ on_select_all (GSimpleAction *action,
                                                  focused))
     /* Assume that other widgets should select all in the file view. */
     {
-        /* Save the current displayed data */
-        ET_Save_File_Data_From_UI (ETCore->ETFileDisplayed);
+        et_application_window_update_et_file_from_ui (self);
 
         et_browser_select_all (ET_BROWSER (priv->browser));
         et_application_window_update_actions (self);
@@ -774,8 +790,7 @@ on_unselect_all (GSimpleAction *action,
                                                    focused))
     /* Assume that other widgets should unselect all in the file view. */
     {
-        /* Save the current displayed data */
-        ET_Save_File_Data_From_UI (ETCore->ETFileDisplayed);
+        et_application_window_update_et_file_from_ui (self);
 
         et_browser_unselect_all (ET_BROWSER (priv->browser));
 
@@ -795,14 +810,13 @@ on_undo_last_changes (GSimpleAction *action,
 
     g_return_if_fail (ETCore->ETFileList != NULL);
 
-    /* Save the current displayed data */
-    ET_Save_File_Data_From_UI (ETCore->ETFileDisplayed);
+    et_application_window_update_et_file_from_ui (self);
 
     ETFile = ET_Undo_History_File_Data ();
 
     if (ETFile)
     {
-        ET_Display_File_Data_To_UI (ETFile);
+        et_application_window_display_et_file (self, ETFile);
         et_application_window_browser_select_file_by_et_file (self, ETFile,
                                                               TRUE);
         et_application_window_browser_refresh_file_in_list (self, ETFile);
@@ -823,14 +837,13 @@ on_redo_last_changes (GSimpleAction *action,
 
     g_return_if_fail (ETCore->ETFileDisplayedList != NULL);
 
-    /* Save the current displayed data */
-    ET_Save_File_Data_From_UI (ETCore->ETFileDisplayed);
+    et_application_window_update_et_file_from_ui (self);
 
     ETFile = ET_Redo_History_File_Data ();
 
     if (ETFile)
     {
-        ET_Display_File_Data_To_UI (ETFile);
+        et_application_window_display_et_file (self, ETFile);
         et_application_window_browser_select_file_by_et_file (self, ETFile,
                                                               TRUE);
         et_application_window_browser_refresh_file_in_list (self, ETFile);
@@ -860,8 +873,7 @@ on_remove_tags (GSimpleAction *action,
     self = ET_APPLICATION_WINDOW (user_data);
     priv = et_application_window_get_instance_private (self);
 
-    /* Save the current displayed data */
-    ET_Save_File_Data_From_UI (ETCore->ETFileDisplayed);
+    et_application_window_update_et_file_from_ui (self);
 
     /* Initialize status bar */
     et_application_window_progress_set_fraction (self, 0.0);
@@ -893,7 +905,7 @@ on_remove_tags (GSimpleAction *action,
     et_application_window_browser_refresh_list (self);
 
     /* Display the current file */
-    ET_Display_File_Data_To_UI (ETCore->ETFileDisplayed);
+    et_application_window_display_et_file (self, ETCore->ETFileDisplayed);
     et_application_window_update_actions (self);
 
     et_application_window_progress_set_fraction (self, 0.0);
@@ -1002,8 +1014,7 @@ on_file_artist_view_change (GSimpleAction *action,
 
     g_return_if_fail (ETCore->ETFileDisplayedList != NULL);
 
-    /* Save the current displayed data. */
-    ET_Save_File_Data_From_UI (ETCore->ETFileDisplayed);
+    et_application_window_update_et_file_from_ui (self);
 
     if (strcmp (state, "file") == 0)
     {
@@ -1261,34 +1272,20 @@ on_go_default (GSimpleAction *action,
 }
 
 static void
-on_go_first (GSimpleAction *action,
-             GVariant *variant,
-             gpointer user_data)
+update_ui_for_et_file (EtApplicationWindow *self,
+                       ET_File *et_file)
 {
     EtApplicationWindowPrivate *priv;
-    EtApplicationWindow *self;
-    GList *etfilelist;
 
-    self = ET_APPLICATION_WINDOW (user_data);
     priv = et_application_window_get_instance_private (self);
 
-    if (!ETCore->ETFileDisplayedList)
-        return;
-
-    /* Save the current displayed data */
-    ET_Save_File_Data_From_UI (ETCore->ETFileDisplayed);
-
-    /* Go to the first item of the list */
-    etfilelist = ET_Displayed_File_List_First ();
-
-    if (etfilelist)
+    if (et_file)
     {
         /* To avoid the last line still selected. */
         et_browser_unselect_all (ET_BROWSER (priv->browser));
-        et_application_window_browser_select_file_by_et_file (self,
-                                                              (ET_File *)etfilelist->data,
+        et_application_window_browser_select_file_by_et_file (self, et_file,
                                                               TRUE);
-        ET_Display_File_Data_To_UI ((ET_File *)etfilelist->data);
+        et_application_window_display_et_file (self, et_file);
     }
 
     et_application_window_update_actions (self);
@@ -1300,43 +1297,47 @@ on_go_first (GSimpleAction *action,
     }
 }
 
+static void
+on_go_first (GSimpleAction *action,
+             GVariant *variant,
+             gpointer user_data)
+{
+    EtApplicationWindow *self;
+    GList *etfilelist;
+
+    self = ET_APPLICATION_WINDOW (user_data);
+
+    g_return_if_fail (ETCore->ETFileDisplayedList);
+
+    et_application_window_update_et_file_from_ui (self);
+
+    /* Go to the first item of the list */
+    etfilelist = ET_Displayed_File_List_First ();
+
+    update_ui_for_et_file (self, etfilelist ? (ET_File *)etfilelist->data
+                                            : NULL);
+}
+
 static void
 on_go_previous (GSimpleAction *action,
                 GVariant *variant,
                 gpointer user_data)
 {
-    EtApplicationWindowPrivate *priv;
     EtApplicationWindow *self;
     GList *etfilelist;
 
     self = ET_APPLICATION_WINDOW (user_data);
-    priv = et_application_window_get_instance_private (self);
 
-    if (!ETCore->ETFileDisplayedList || !ETCore->ETFileDisplayedList->prev)
-        return;
+    g_return_if_fail (ETCore->ETFileDisplayedList
+                      && ETCore->ETFileDisplayedList->prev);
 
-    /* Save the current displayed data */
-    ET_Save_File_Data_From_UI (ETCore->ETFileDisplayed);
+    et_application_window_update_et_file_from_ui (self);
 
     /* Go to the prev item of the list */
     etfilelist = ET_Displayed_File_List_Previous ();
 
-    if (etfilelist)
-    {
-        et_browser_unselect_all (ET_BROWSER (priv->browser));
-        et_application_window_browser_select_file_by_et_file (self,
-                                                              (ET_File *)etfilelist->data,
-                                                              TRUE);
-        ET_Display_File_Data_To_UI((ET_File *)etfilelist->data);
-    }
-
-    et_application_window_update_actions (self);
-    et_application_window_scan_dialog_update_previews (self);
-
-    if (!g_settings_get_boolean (MainSettings, "tag-preserve-focus"))
-    {
-        et_tag_area_title_grab_focus (ET_TAG_AREA (priv->tag_area));
-    }
+    update_ui_for_et_file (self, etfilelist ? (ET_File *)etfilelist->data
+                                            : NULL);
 }
 
 static void
@@ -1344,38 +1345,21 @@ on_go_next (GSimpleAction *action,
             GVariant *variant,
             gpointer user_data)
 {
-    EtApplicationWindowPrivate *priv;
     EtApplicationWindow *self;
     GList *etfilelist;
 
     self = ET_APPLICATION_WINDOW (user_data);
-    priv = et_application_window_get_instance_private (self);
 
-    if (!ETCore->ETFileDisplayedList || !ETCore->ETFileDisplayedList->next)
-        return;
+    g_return_if_fail (ETCore->ETFileDisplayedList
+                      && ETCore->ETFileDisplayedList->next);
 
-    /* Save the current displayed data */
-    ET_Save_File_Data_From_UI (ETCore->ETFileDisplayed);
+    et_application_window_update_et_file_from_ui (self);
 
     /* Go to the next item of the list */
     etfilelist = ET_Displayed_File_List_Next ();
 
-    if (etfilelist)
-    {
-        et_browser_unselect_all (ET_BROWSER (priv->browser));
-        et_application_window_browser_select_file_by_et_file (self,
-                                                              (ET_File *)etfilelist->data,
-                                                              TRUE);
-        ET_Display_File_Data_To_UI((ET_File *)etfilelist->data);
-    }
-
-    et_application_window_update_actions (self);
-    et_application_window_scan_dialog_update_previews (self);
-
-    if (!g_settings_get_boolean (MainSettings, "tag-preserve-focus"))
-    {
-        et_tag_area_title_grab_focus (ET_TAG_AREA (priv->tag_area));
-    }
+    update_ui_for_et_file (self, etfilelist ? (ET_File *)etfilelist->data
+                                            : NULL);
 }
 
 static void
@@ -1383,38 +1367,21 @@ on_go_last (GSimpleAction *action,
             GVariant *variant,
             gpointer user_data)
 {
-    EtApplicationWindowPrivate *priv;
     EtApplicationWindow *self;
     GList *etfilelist;
 
     self = ET_APPLICATION_WINDOW (user_data);
-    priv = et_application_window_get_instance_private (self);
 
-    if (!ETCore->ETFileDisplayedList || !ETCore->ETFileDisplayedList->next)
-        return;
+    g_return_if_fail (ETCore->ETFileDisplayedList
+                      && ETCore->ETFileDisplayedList->next);
 
-    /* Save the current displayed data */
-    ET_Save_File_Data_From_UI (ETCore->ETFileDisplayed);
+    et_application_window_update_et_file_from_ui (self);
 
     /* Go to the last item of the list */
     etfilelist = ET_Displayed_File_List_Last ();
 
-    if (etfilelist)
-    {
-        et_browser_unselect_all (ET_BROWSER (priv->browser));
-        et_application_window_browser_select_file_by_et_file (self,
-                                                              (ET_File *)etfilelist->data,
-                                                              TRUE);
-        ET_Display_File_Data_To_UI ((ET_File *)etfilelist->data);
-    }
-
-    et_application_window_update_actions (self);
-    et_application_window_scan_dialog_update_previews (self);
-
-    if (!g_settings_get_boolean (MainSettings, "tag-preserve-focus"))
-    {
-        et_tag_area_title_grab_focus (ET_TAG_AREA (priv->tag_area));
-    }
+    update_ui_for_et_file (self, etfilelist ? (ET_File *)etfilelist->data
+                                            : NULL);
 }
 
 static void
@@ -1997,19 +1964,373 @@ et_application_window_select_file_by_et_file (EtApplicationWindow *self,
     if (!ETCore->ETFileDisplayedList)
         return;
 
-    /* Save the current displayed data */
-    ET_Save_File_Data_From_UI (ETCore->ETFileDisplayed);
+    et_application_window_update_et_file_from_ui (self);
 
     /* Display the item */
     et_application_window_browser_select_file_by_et_file (self, ETFile, TRUE);
     /* Just to update 'ETFileDisplayedList'. */
     ET_Displayed_File_List_By_Etfile (ETFile);
-    ET_Display_File_Data_To_UI (ETFile);
+    et_application_window_display_et_file (self, ETFile);
 
     et_application_window_update_actions (self);
     et_application_window_scan_dialog_update_previews (self);
 }
 
+/*
+ * Save displayed filename into list if it had been changed. Generates also an history list for undo/redo.
+ *  - ETFile : the current etfile that we want to save,
+ *  - FileName : where is 'temporary' saved the new filename.
+ *
+ * Note : it builds new filename (with path) from strings encoded into file system
+ *        encoding, not UTF-8 (it preserves file system encoding of parent directories).
+ */
+static void
+et_application_window_update_file_name_from_ui (EtApplicationWindow *self,
+                                                const ET_File *ETFile,
+                                                File_Name *FileName)
+{
+    gchar *filename_new = NULL;
+    gchar *dirname = NULL;
+    gchar *filename;
+    const gchar *filename_utf8;
+    gchar *extension;
+
+    g_return_if_fail (ETFile != NULL && FileName != NULL);
+
+    filename_utf8 = et_application_window_file_area_get_filename (self);
+    filename = filename_from_display (filename_utf8);
+
+    if (!filename)
+    {
+        /* If conversion fails... */
+        GtkWidget *msgdialog;
+        gchar *filename_escaped_utf8 = g_strescape(filename_utf8, NULL);
+        msgdialog = gtk_message_dialog_new (GTK_WINDOW (self),
+                                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                            GTK_MESSAGE_ERROR,
+                                            GTK_BUTTONS_CLOSE,
+                                            _("Could not convert filename ‘%s’ to system filename encoding"),
+                                            filename_escaped_utf8);
+        gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (msgdialog),
+                                                  _("Try setting the environment variable G_FILENAME_ENCODING."));
+        gtk_window_set_title (GTK_WINDOW (msgdialog),
+                              _("Filename translation"));
+
+        gtk_dialog_run (GTK_DIALOG (msgdialog));
+        gtk_widget_destroy (msgdialog);
+        g_free (filename_escaped_utf8);
+        return;
+    }
+
+    /* Get the current path to the file. */
+    dirname = g_path_get_dirname (((File_Name *)ETFile->FileNameNew->data)->value);
+
+    /* Convert filename extension (lower or upper). */
+    extension = ET_File_Format_File_Extension (ETFile);
+
+    // Check length of filename (limit ~255 characters)
+    //ET_File_Name_Check_Length(ETFile,filename);
+
+    /* Filename (in file system encoding!). */
+    if (filename && *filename)
+    {
+        /* Regenerate the new filename (without path). */
+        filename_new = g_strconcat (filename, extension, NULL);
+    }
+    else
+    {
+        /* Keep the 'last' filename (if a 'blank' filename was entered in the
+         * fileentry for example). */
+        filename_new = g_path_get_basename (((File_Name *)ETFile->FileNameNew->data)->value);
+    }
+
+    g_free (filename);
+    g_free (extension);
+
+    et_file_name_set_from_components (FileName, filename_new, dirname,
+                                      g_settings_get_boolean (MainSettings,
+                                                              "rename-replace-illegal-chars"));
+
+    g_free (filename_new);
+    g_free (dirname);
+    return;
+}
+
+void
+et_application_window_update_et_file_from_ui (EtApplicationWindow *self)
+{
+    const ET_File_Description *description;
+    ET_File *et_file;
+    File_Name *FileName;
+    File_Tag  *FileTag;
+    const gchar *cur_filename_utf8;
+
+    if (!ETCore->ETFileDisplayed)
+    {
+        return;
+    }
+
+    et_file = ETCore->ETFileDisplayed;
+
+    g_return_if_fail (et_file != NULL && et_file->FileNameCur != NULL
+                      && et_file->FileNameCur->data != NULL);
+
+    /* Save the current displayed data */
+    cur_filename_utf8 = ((File_Name *)((GList *)et_file->FileNameCur)->data)->value_utf8;
+    description = et_file->ETFileDescription;
+
+    /* Save filename and generate undo for filename. */
+    FileName = et_file_name_new ();
+    et_application_window_update_file_name_from_ui (self, et_file, FileName);
+
+    switch (description->TagType)
+    {
+#ifdef ENABLE_MP3
+        case ID3_TAG:
+#endif
+#ifdef ENABLE_OGG
+        case OGG_TAG:
+#endif
+#ifdef ENABLE_FLAC
+        case FLAC_TAG:
+#endif
+#ifdef ENABLE_MP4
+        case MP4_TAG:
+#endif
+#ifdef ENABLE_WAVPACK
+        case WAVPACK_TAG:
+#endif
+#ifdef ENABLE_OPUS
+        case OPUS_TAG:
+#endif
+        case APE_TAG:
+            FileTag = et_application_window_tag_area_create_file_tag (self);
+            et_file_tag_copy_other_into (et_file->FileTag->data, FileTag);
+            break;
+        case UNKNOWN_TAG:
+        default:
+            FileTag = et_file_tag_new ();
+            Log_Print (LOG_ERROR,
+                       "FileTag: Undefined tag type %d for file %s.",
+                       (gint)description->TagType, cur_filename_utf8);
+            break;
+    }
+
+    /*
+     * Generate undo for the file and the main undo list.
+     * If no changes detected, FileName and FileTag item are deleted.
+     */
+    ET_Manage_Changes_Of_File_Data (et_file, FileName, FileTag);
+
+    /* Refresh file into browser list */
+    et_application_window_browser_refresh_file_in_list (self, et_file);
+}
+
+static void
+et_file_header_fields_free (EtFileHeaderFields *fields)
+{
+    g_free (fields->version);
+    g_free (fields->bitrate);
+    g_free (fields->samplerate);
+    g_free (fields->mode);
+    g_free (fields->size);
+    g_free (fields->duration);
+    g_slice_free (EtFileHeaderFields, fields);
+}
+
+static void
+et_application_window_display_file_name (EtApplicationWindow *self,
+                                         const ET_File *ETFile)
+{
+    const gchar *new_filename_utf8;
+    gchar *dirname_utf8;
+    gchar *text;
+
+    g_return_if_fail (ETFile != NULL);
+
+    new_filename_utf8 = ((File_Name *)((GList *)ETFile->FileNameNew)->data)->value_utf8;
+
+    /*
+     * Set the path to the file into BrowserEntry (dirbrowser)
+     */
+    dirname_utf8 = g_path_get_dirname (new_filename_utf8);
+    et_application_window_browser_entry_set_text (self, dirname_utf8);
+
+    // And refresh the number of files in this directory
+    text = g_strdup_printf (ngettext ("One file", "%u files",
+                                      et_file_list_get_n_files_in_path (ETCore->ETFileList,
+                                                                        dirname_utf8)),
+                            et_file_list_get_n_files_in_path (ETCore->ETFileList,
+                                                              dirname_utf8));
+    et_application_window_browser_label_set_text (self, text);
+    g_free(dirname_utf8);
+    g_free(text);
+}
+
+/*
+ * "Default" way to display File Info to the user interface.
+ */
+static EtFileHeaderFields *
+et_header_fields_new_from_unknown (const ET_File *ETFile)
+{
+    EtFileHeaderFields *fields;
+    ET_File_Info *info;
+    gchar *time  = NULL;
+    gchar *time1 = NULL;
+    gchar *size  = NULL;
+    gchar *size1 = NULL;
+
+    info = ETFile->ETFileInfo;
+    fields = g_slice_new (EtFileHeaderFields);
+
+    fields->description = _("File");
+
+    /* MPEG, Layer versions */
+    fields->version = g_strdup_printf ("%d, Layer %" G_GSIZE_FORMAT,
+                                       info->version, info->layer);
+
+    /* Bitrate */
+    fields->bitrate = g_strdup_printf (_("%d kb/s"), info->bitrate);
+
+    /* Samplerate */
+    fields->samplerate = g_strdup_printf (_("%d Hz"), info->samplerate);
+
+    /* Mode */
+    fields->mode = g_strdup_printf ("%d", info->mode);
+
+    /* Size */
+    size = g_format_size (info->size);
+    size1 = g_format_size (ETCore->ETFileDisplayedList_TotalSize);
+    fields->size = g_strdup_printf ("%s (%s)", size, size1);
+    g_free (size);
+    g_free (size1);
+
+    /* Duration */
+    time = Convert_Duration (info->duration);
+    time1 = Convert_Duration (ETCore->ETFileDisplayedList_TotalDuration);
+    fields->duration = g_strdup_printf ("%s (%s)", time, time1);
+    g_free (time);
+    g_free (time1);
+
+    return fields;
+}
+
+/*
+ * Display information of the file (Position + Header + Tag) to the user interface.
+ * Before doing it, it saves data of the file currently displayed
+ */
+void
+et_application_window_display_et_file (EtApplicationWindow *self,
+                                       ET_File *ETFile)
+{
+    const ET_File_Description *description;
+    const gchar *cur_filename_utf8;
+    gchar *msg;
+    EtFileHeaderFields *fields;
+
+    g_return_if_fail (ETFile != NULL &&
+                      ((GList *)ETFile->FileNameCur)->data != NULL);
+                      /* For the case where ETFile is an "empty" structure. */
+
+    cur_filename_utf8 = ((File_Name *)((GList *)ETFile->FileNameCur)->data)->value_utf8;
+    description = ETFile->ETFileDescription;
+
+    /* Save the current displayed file */
+    ETCore->ETFileDisplayed = ETFile;
+
+    /* Display position in list + show/hide icon if file writable/read_only (cur_filename) */
+    et_application_window_file_area_set_file_fields (self, ETFile);
+
+    /* Display filename (and his path) (value in FileNameNew) */
+    et_application_window_display_file_name (self, ETFile);
+
+    /* Display tag data */
+    et_application_window_tag_area_display_et_file (self, ETFile);
+
+    /* Display controls in tag area */
+    et_application_window_tag_area_display_controls (self, ETFile);
+
+    /* Display file data, header data and file type */
+    switch (description->FileType)
+    {
+#if defined ENABLE_MP3 && defined ENABLE_ID3LIB
+        case MP3_FILE:
+        case MP2_FILE:
+            fields = et_mpeg_header_display_file_info_to_ui (ETFile);
+            et_application_window_file_area_set_header_fields (self, fields);
+            et_mpeg_file_header_fields_free (fields);
+            break;
+#endif
+#ifdef ENABLE_OGG
+        case OGG_FILE:
+            fields = et_ogg_header_display_file_info_to_ui (ETFile);
+            et_application_window_file_area_set_header_fields (self, fields);
+            et_ogg_file_header_fields_free (fields);
+            break;
+#endif
+#ifdef ENABLE_SPEEX
+        case SPEEX_FILE:
+            fields = et_ogg_header_display_file_info_to_ui (ETFile);
+            et_application_window_file_area_set_header_fields (self, fields);
+            et_ogg_file_header_fields_free (fields);
+            break;
+#endif
+#ifdef ENABLE_FLAC
+        case FLAC_FILE:
+            fields = et_flac_header_display_file_info_to_ui (ETFile);
+            et_application_window_file_area_set_header_fields (self, fields);
+            et_flac_file_header_fields_free (fields);
+            break;
+#endif
+        case MPC_FILE:
+            fields = et_mpc_header_display_file_info_to_ui (ETFile);
+            et_application_window_file_area_set_header_fields (self, fields);
+            et_mpc_file_header_fields_free (fields);
+            break;
+        case MAC_FILE:
+            fields = et_mac_header_display_file_info_to_ui (ETFile);
+            et_application_window_file_area_set_header_fields (self, fields);
+            et_mac_file_header_fields_free (fields);
+            break;
+#ifdef ENABLE_MP4
+        case MP4_FILE:
+            fields = et_mp4_header_display_file_info_to_ui (ETFile);
+            et_application_window_file_area_set_header_fields (self, fields);
+            et_mp4_file_header_fields_free (fields);
+            break;
+#endif
+#ifdef ENABLE_WAVPACK
+        case WAVPACK_FILE:
+            fields = et_wavpack_header_display_file_info_to_ui (ETFile);
+            et_application_window_file_area_set_header_fields (self, fields);
+            et_wavpack_file_header_fields_free (fields);
+            break;
+#endif
+#ifdef ENABLE_OPUS
+        case OPUS_FILE:
+            fields = et_opus_header_display_file_info_to_ui (ETFile);
+            et_application_window_file_area_set_header_fields (self, fields);
+            et_opus_file_header_fields_free (fields);
+            break;
+#endif
+        case OFR_FILE:
+        case UNKNOWN_FILE:
+        default:
+            /* Default displaying. */
+            fields = et_header_fields_new_from_unknown (ETFile);
+            et_application_window_file_area_set_header_fields (self, fields);
+            et_file_header_fields_free (fields);
+            Log_Print (LOG_ERROR,
+                       "ETFileInfo: Undefined file type %d for file %s.",
+                       (gint)description->FileType, cur_filename_utf8);
+            break;
+    }
+
+    msg = g_strdup_printf (_("File: ‘%s’"), cur_filename_utf8);
+    et_application_window_status_bar_message (self, msg, FALSE);
+    g_free (msg);
+}
+
 const gchar *
 et_application_window_get_current_path (EtApplicationWindow *self)
 {
@@ -2594,8 +2915,7 @@ et_application_window_browser_unselect_all (EtApplicationWindow *self)
 
     priv = et_application_window_get_instance_private (self);
 
-    /* Save the current displayed data */
-    ET_Save_File_Data_From_UI (ETCore->ETFileDisplayed);
+    et_application_window_update_et_file_from_ui (self);
 
     et_browser_unselect_all (ET_BROWSER (priv->browser));
     ETCore->ETFileDisplayed = NULL;
@@ -2655,10 +2975,7 @@ et_application_window_quit (EtApplicationWindow *self)
     gint response;
 
     /* If you change the displayed data and quit immediately */
-    if (ETCore->ETFileList)
-    {
-        ET_Save_File_Data_From_UI (ETCore->ETFileDisplayed);
-    }
+    et_application_window_update_et_file_from_ui (self);
 
     /* Check if all files have been saved before exit */
     if (g_settings_get_boolean (MainSettings, "confirm-when-unsaved-files")
