@@ -151,7 +151,7 @@ check_locale (const char *locale)
 
 /* stolen from gnome-desktop-item.c */
 G_GNUC_NULL_TERMINATED static void
-insert_locales (GHashTable *encodings, const gchar *enc, ...)
+insert_locales (GHashTable *encs, const gchar *enc, ...)
 {
     va_list args;
     char *s;
@@ -164,7 +164,7 @@ insert_locales (GHashTable *encodings, const gchar *enc, ...)
             break;
         /* A GDestroyNotify is not passed, so casting away the const is
          * safe, as the key is never freed. */
-        g_hash_table_insert (encodings, s, (gpointer)enc);
+        g_hash_table_insert (encs, s, (gpointer)enc);
     }
     va_end (args);
 }
@@ -712,34 +712,10 @@ Charset_Populate_Combobox (GtkComboBox *combo, gint select_charset)
     gtk_combo_box_set_active (combo, select_charset);
 }
 
-
-/*
- * Return charset_name from charset_title
- */
 const gchar *
-Charset_Get_Name_From_Title (const gchar *charset_title)
+et_charset_get_name_from_index (guint index)
 {
-    guint i;
-
-    g_return_val_if_fail (charset_title != NULL, NULL);
-
-    for (i = 0; i < CHARSET_TRANS_ARRAY_LEN; i++)
-    {
-        if (strcasecmp (_(charset_title),
-                        _(charset_trans_array[i].charset_title)) == 0)
-        {
-            return charset_trans_array[i].charset_name;
-        }
-    }
-
-    return NULL;
-}
-
-const gchar *
-et_charset_get_name_from_index (gint index)
-{
-    g_return_val_if_fail (index >= 0 && index <= CHARSET_TRANS_ARRAY_LEN,
-                          NULL);
+    g_return_val_if_fail (index <= CHARSET_TRANS_ARRAY_LEN, NULL);
 
     return charset_trans_array[index].charset_name;
 }
