@@ -166,8 +166,7 @@ Save_List_Of_Files (GList *etfilelist, gboolean force_saving_files)
     /* Save the current position in the list */
     etfile_save_position = ETCore->ETFileDisplayed;
 
-    /* Save the current displayed data */
-    ET_Save_File_Data_From_UI(ETCore->ETFileDisplayed);
+    et_application_window_update_et_file_from_ui (window);
 
     /* Save widget that has current focus, to give it again the focus after saving */
     widget_focused = gtk_window_get_focus(GTK_WINDOW(MainWindow));
@@ -348,7 +347,8 @@ Save_List_Of_Files (GList *etfilelist, gboolean force_saving_files)
     g_simple_action_set_enabled (G_SIMPLE_ACTION (action), FALSE);
 
     /* Return to the saved position in the list */
-    ET_Display_File_Data_To_UI(etfile_save_position);
+    et_application_window_display_et_file (ET_APPLICATION_WINDOW (MainWindow),
+                                           etfile_save_position);
     et_application_window_browser_select_file_by_et_file (ET_APPLICATION_WINDOW (MainWindow),
                                                           etfile_save_position,
                                                           TRUE);
@@ -997,7 +997,7 @@ Read_Directory (const gchar *path_real)
     nbrfile = g_list_length(FileList);
 
     et_application_window_progress_set_fraction (window, 0.0);
-    g_snprintf(progress_bar_text, 30, "%d/%d", 0, nbrfile);
+    g_snprintf (progress_bar_text, 30, "%d/%u", 0, nbrfile);
     et_application_window_progress_set_text (window, progress_bar_text);
 
     // Load the supported files (Extension recognized)
@@ -1020,7 +1020,8 @@ Read_Directory (const gchar *path_real)
         /* Update the progress bar. */
         fraction = (++progress_bar_index) / (double) nbrfile;
         et_application_window_progress_set_fraction (window, fraction);
-        g_snprintf(progress_bar_text, 30, "%d/%d", progress_bar_index, nbrfile);
+        g_snprintf (progress_bar_text, 30, "%d/%u", progress_bar_index,
+                    nbrfile);
         et_application_window_progress_set_text (window, progress_bar_text);
         while (gtk_events_pending())
             gtk_main_iteration();
@@ -1057,14 +1058,14 @@ Read_Directory (const gchar *path_real)
         if (g_settings_get_boolean (MainSettings, "browse-subdir"))
         {
             msg = g_strdup_printf (ngettext ("Found one file in this directory and subdirectories",
-                                             "Found %d files in this directory and subdirectories",
+                                             "Found %u files in this directory and subdirectories",
                                              ETCore->ETFileDisplayedList_Length),
                                    ETCore->ETFileDisplayedList_Length);
         }
         else
         {
             msg = g_strdup_printf (ngettext ("Found one file in this directory",
-                                             "Found %d files in this directory",
+                                             "Found %u files in this directory",
                                              ETCore->ETFileDisplayedList_Length),
                                    ETCore->ETFileDisplayedList_Length);
         }
