@@ -20,7 +20,6 @@
 
 #include "file.h"
 
-#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <string.h>
 #include <stdlib.h>
@@ -32,33 +31,25 @@
 #include "easytag.h"
 #include "file_tag.h"
 #include "file_list.h"
-#include "mpeg_header.h"
-#include "monkeyaudio_header.h"
-#include "musepack_header.h"
 #ifdef ENABLE_MP3
 #   include "id3_tag.h"
 #endif
 #include "picture.h"
 #include "ape_tag.h"
 #ifdef ENABLE_OGG
-#   include "ogg_header.h"
-#   include "ogg_tag.h"
+#include "ogg_tag.h"
 #endif
 #ifdef ENABLE_FLAC
-#   include "flac_header.h"
-#   include "flac_tag.h"
+#include "flac_tag.h"
 #endif
 #ifdef ENABLE_MP4
-#   include "mp4_header.h"
-#   include "mp4_tag.h"
+#include "mp4_tag.h"
 #endif
 #ifdef ENABLE_WAVPACK
-#   include "wavpack_header.h"
-#   include "wavpack_tag.h"
+#include "wavpack_tag.h"
 #endif
 #ifdef ENABLE_OPUS
 #include "opus_tag.h"
-#include "opus_header.h"
 #endif
 #include "browser.h"
 #include "log.h"
@@ -70,53 +61,13 @@
 
 static gboolean ET_Free_File_Name_List            (GList *FileNameList);
 static gboolean ET_Free_File_Tag_List (GList *FileTagList);
-static void ET_Free_File_Name_Item (File_Name *FileName);
-static gboolean ET_Free_File_Info_Item (ET_File_Info *ETFileInfo);
-
-static void ET_Initialize_File_Name_Item (File_Name *FileName);
-
-static void ET_Display_Filename_To_UI (const ET_File *ETFile);
-static EtFileHeaderFields * ET_Display_File_Info_To_UI (const ET_File *ETFile);
-
-static gboolean ET_Save_File_Name_From_UI (const ET_File *ETFile,
-                                           File_Name *FileName);
 
 static void ET_Mark_File_Tag_As_Saved (ET_File *ETFile);
 
-static gboolean ET_Detect_Changes_Of_File_Name (const File_Name *FileName1,
-                                                const File_Name *FileName2);
 static gboolean ET_Add_File_Name_To_List (ET_File *ETFile,
                                           File_Name *FileName);
 static gboolean ET_Add_File_Tag_To_List (ET_File *ETFile, File_Tag  *FileTag);
 
-static gchar *ET_File_Name_Format_Extension (const ET_File *ETFile);
-
-/*
- * Create a new File_Name structure
- */
-File_Name *ET_File_Name_Item_New (void)
-{
-    File_Name *FileName;
-
-    FileName = g_slice_new (File_Name);
-    ET_Initialize_File_Name_Item (FileName);
-
-    return FileName;
-}
-
-/*
- * Create a new File_Info structure
- */
-ET_File_Info *
-ET_File_Info_Item_New (void)
-{
-    ET_File_Info *ETFileInfo;
-
-    ETFileInfo = g_slice_new0 (ET_File_Info);
-
-    return ETFileInfo;
-}
-
 /*
  * Create a new ET_File structure
  */
@@ -130,28 +81,6 @@ ET_File_Item_New (void)
     return ETFile;
 }
 
-
-static void
-ET_Initialize_File_Name_Item (File_Name *FileName)
-{
-    if (FileName)
-    {
-        FileName->key        = ET_Undo_Key_New();
-        FileName->saved      = FALSE;
-        FileName->value      = NULL;
-        FileName->value_utf8 = NULL;
-        FileName->value_ck   = NULL;
-    }
-}
-
-/* Key for Undo */
-guint
-ET_Undo_Key_New (void)
-{
-    static guint ETUndoKey = 0;
-    return ++ETUndoKey;
-}
-
 /*
  * Comparison function for sorting by ascending filename.
  */
@@ -1054,7 +983,7 @@ ET_Free_File_List_Item (ET_File *ETFile)
         /* Frees infos of ETFileInfo */
         if (ETFile->ETFileInfo)
         {
-            ET_Free_File_Info_Item (ETFile->ETFileInfo);
+            et_file_info_free (ETFile->ETFileInfo);
         }
 
         g_free(ETFile->ETFileExtension);
@@ -1073,27 +1002,11 @@ ET_Free_File_Name_List (GList *FileNameList)
 
     FileNameList = g_list_first (FileNameList);
 
-    g_list_free_full (FileNameList, (GDestroyNotify)ET_Free_File_Name_Item);
+    g_list_free_full (FileNameList, (GDestroyNotify)et_file_name_free);
 
     return TRUE;
 }
 
-
-/*
- * Frees a File_Name item.
- */
-static void
-ET_Free_File_Name_Item (File_Name *FileName)
-{
-    g_return_if_fail (FileName != NULL);
-
-    g_free(FileName->value);
-    g_free(FileName->value_utf8);
-    g_free(FileName->value_ck);
-    g_slice_free (File_Name, FileName);
-}
-
-
 /*
  * Frees the full list: GList *TagList.
  */
@@ -1120,444 +1033,14 @@ ET_Free_File_Tag_List (GList *FileTagList)
 }
 
 
-/*
- * Frees a File_Info item.
- */
-static gboolean
-ET_Free_File_Info_Item (ET_File_Info *ETFileInfo)
-{
-    g_return_val_if_fail (ETFileInfo != NULL, FALSE);
-
-    g_free(ETFileInfo->mpc_profile);
-    g_free(ETFileInfo->mpc_version);
-
-    g_slice_free (ET_File_Info, ETFileInfo);
-    return TRUE;
-}
-
-
 /*********************
  * Copying functions *
  *********************/
 
-/*
- * Fill content of a FileName item according to the filename passed in argument (UTF-8 filename or not)
- * Calculate also the collate key.
- * It treats numbers intelligently so that "file1" "file10" "file5" is sorted as "file1" "file5" "file10"
- */
-gboolean
-ET_Set_Filename_File_Name_Item (File_Name *FileName,
-                                const gchar *filename_utf8,
-                                const gchar *filename)
-{
-    g_return_val_if_fail (FileName != NULL, FALSE);
-
-    if (filename_utf8 && filename)
-    {
-        FileName->value_utf8 = g_strdup(filename_utf8);
-        FileName->value      = g_strdup(filename);
-        FileName->value_ck   = g_utf8_collate_key_for_filename(FileName->value_utf8, -1);
-    }else if (filename_utf8)
-    {
-        FileName->value_utf8 = g_strdup(filename_utf8);
-        FileName->value      = filename_from_display(filename_utf8);
-        FileName->value_ck   = g_utf8_collate_key_for_filename(FileName->value_utf8, -1);
-    }else if (filename)
-    {
-        FileName->value_utf8 = filename_to_display(filename);;
-        FileName->value      = g_strdup(filename);
-        FileName->value_ck   = g_utf8_collate_key_for_filename(FileName->value_utf8, -1);
-    }else
-    {
-        return FALSE;
-    }
-
-    return TRUE;
-}
-
-/************************
- * Displaying functions *
- ************************/
-
-static void
-et_file_header_fields_free (EtFileHeaderFields *fields)
-{
-    g_free (fields->version);
-    g_free (fields->bitrate);
-    g_free (fields->samplerate);
-    g_free (fields->mode);
-    g_free (fields->size);
-    g_free (fields->duration);
-    g_slice_free (EtFileHeaderFields, fields);
-}
-
-/*
- * Display information of the file (Position + Header + Tag) to the user interface.
- * Before doing it, it saves data of the file currently displayed
- */
-void
-ET_Display_File_Data_To_UI (ET_File *ETFile)
-{
-    EtApplicationWindow *window;
-    const ET_File_Description *description;
-    const gchar *cur_filename_utf8;
-    gchar *msg;
-    EtFileHeaderFields *fields;
-
-    g_return_if_fail (ETFile != NULL &&
-                      ((GList *)ETFile->FileNameCur)->data != NULL);
-                      /* For the case where ETFile is an "empty" structure. */
-
-    cur_filename_utf8 = ((File_Name *)((GList *)ETFile->FileNameCur)->data)->value_utf8;
-    description = ETFile->ETFileDescription;
-
-    /* Save the current displayed file */
-    ETCore->ETFileDisplayed = ETFile;
-
-    window = ET_APPLICATION_WINDOW (MainWindow);
-
-    /* Display position in list + show/hide icon if file writable/read_only (cur_filename) */
-    et_application_window_file_area_set_file_fields (window, ETFile);
-
-    /* Display filename (and his path) (value in FileNameNew) */
-    ET_Display_Filename_To_UI(ETFile);
-
-    /* Display tag data */
-    et_application_window_tag_area_display_et_file (window, ETFile);
-
-    /* Display controls in tag area */
-    et_application_window_tag_area_display_controls (window, ETFile);
-
-    /* Display file data, header data and file type */
-    switch (description->FileType)
-    {
-#if defined ENABLE_MP3 && defined ENABLE_ID3LIB
-        case MP3_FILE:
-        case MP2_FILE:
-            fields = et_mpeg_header_display_file_info_to_ui (ETFile);
-            et_application_window_file_area_set_header_fields (window, fields);
-            et_mpeg_file_header_fields_free (fields);
-            break;
-#endif
-#ifdef ENABLE_OGG
-        case OGG_FILE:
-            fields = et_ogg_header_display_file_info_to_ui (ETFile);
-            et_application_window_file_area_set_header_fields (window, fields);
-            et_ogg_file_header_fields_free (fields);
-            break;
-#endif
-#ifdef ENABLE_SPEEX
-        case SPEEX_FILE:
-            fields = et_ogg_header_display_file_info_to_ui (ETFile);
-            et_application_window_file_area_set_header_fields (window, fields);
-            et_ogg_file_header_fields_free (fields);
-            break;
-#endif
-#ifdef ENABLE_FLAC
-        case FLAC_FILE:
-            fields = et_flac_header_display_file_info_to_ui (ETFile);
-            et_application_window_file_area_set_header_fields (window, fields);
-            et_flac_file_header_fields_free (fields);
-            break;
-#endif
-        case MPC_FILE:
-            fields = et_mpc_header_display_file_info_to_ui (ETFile);
-            et_application_window_file_area_set_header_fields (window, fields);
-            et_mpc_file_header_fields_free (fields);
-            break;
-        case MAC_FILE:
-            fields = et_mac_header_display_file_info_to_ui (ETFile);
-            et_application_window_file_area_set_header_fields (window, fields);
-            et_mac_file_header_fields_free (fields);
-            break;
-#ifdef ENABLE_MP4
-        case MP4_FILE:
-            fields = et_mp4_header_display_file_info_to_ui (ETFile);
-            et_application_window_file_area_set_header_fields (window, fields);
-            et_mp4_file_header_fields_free (fields);
-            break;
-#endif
-#ifdef ENABLE_WAVPACK
-        case WAVPACK_FILE:
-            fields = et_wavpack_header_display_file_info_to_ui (ETFile);
-            et_application_window_file_area_set_header_fields (window, fields);
-            et_wavpack_file_header_fields_free (fields);
-            break;
-#endif
-#ifdef ENABLE_OPUS
-        case OPUS_FILE:
-            fields = et_opus_header_display_file_info_to_ui (ETFile);
-            et_application_window_file_area_set_header_fields (window, fields);
-            et_opus_file_header_fields_free (fields);
-            break;
-#endif
-        case OFR_FILE:
-        case UNKNOWN_FILE:
-        default:
-            /* Default displaying. */
-            fields = ET_Display_File_Info_To_UI (ETFile);
-            et_application_window_file_area_set_header_fields (window, fields);
-            et_file_header_fields_free (fields);
-            Log_Print (LOG_ERROR,
-                       "ETFileInfo: Undefined file type %d for file %s.",
-                       description->FileType, cur_filename_utf8);
-            break;
-    }
-
-    msg = g_strdup_printf (_("File: ‘%s’"), cur_filename_utf8);
-    et_application_window_status_bar_message (window, msg, FALSE);
-    g_free (msg);
-}
-
-static void
-ET_Display_Filename_To_UI (const ET_File *ETFile)
-{
-    const gchar *new_filename_utf8;
-    gchar *dirname_utf8;
-    gchar *text;
-
-    g_return_if_fail (ETFile != NULL);
-
-    new_filename_utf8 = ((File_Name *)((GList *)ETFile->FileNameNew)->data)->value_utf8;
-
-    /*
-     * Set the path to the file into BrowserEntry (dirbrowser)
-     */
-    dirname_utf8 = g_path_get_dirname(new_filename_utf8);
-    et_application_window_browser_entry_set_text (ET_APPLICATION_WINDOW (MainWindow),
-                                                  dirname_utf8);
-
-    // And refresh the number of files in this directory
-    text = g_strdup_printf (ngettext ("One file", "%u files",
-                                      et_file_list_get_n_files_in_path (ETCore->ETFileList,
-                                                                        dirname_utf8)),
-                            et_file_list_get_n_files_in_path (ETCore->ETFileList,
-                                                              dirname_utf8));
-    et_application_window_browser_label_set_text (ET_APPLICATION_WINDOW (MainWindow),
-                                                  text);
-    g_free(dirname_utf8);
-    g_free(text);
-}
-
-
-/*
- * "Default" way to display File Info to the user interface.
- */
-static EtFileHeaderFields *
-ET_Display_File_Info_To_UI (const ET_File *ETFile)
-{
-    EtFileHeaderFields *fields;
-    ET_File_Info *info;
-    gchar *time  = NULL;
-    gchar *time1 = NULL;
-    gchar *size  = NULL;
-    gchar *size1 = NULL;
-
-    info = ETFile->ETFileInfo;
-    fields = g_slice_new (EtFileHeaderFields);
-
-    fields->description = _("File");
-
-    /* MPEG, Layer versions */
-    fields->version = g_strdup_printf ("%d, Layer %" G_GSIZE_FORMAT,
-                                       info->version, info->layer);
-
-    /* Bitrate */
-    fields->bitrate = g_strdup_printf (_("%d kb/s"), info->bitrate);
-
-    /* Samplerate */
-    fields->samplerate = g_strdup_printf (_("%d Hz"), info->samplerate);
-
-    /* Mode */
-    fields->mode = g_strdup_printf ("%d", info->mode);
-
-    /* Size */
-    size = g_format_size (info->size);
-    size1 = g_format_size (ETCore->ETFileDisplayedList_TotalSize);
-    fields->size = g_strdup_printf ("%s (%s)", size, size1);
-    g_free (size);
-    g_free (size1);
-
-    /* Duration */
-    time = Convert_Duration (info->duration);
-    time1 = Convert_Duration (ETCore->ETFileDisplayedList_TotalDuration);
-    fields->duration = g_strdup_printf ("%s (%s)", time, time1);
-    g_free (time);
-    g_free (time1);
-
-    return fields;
-}
-
 /********************
  * Saving functions *
  ********************/
 
-/*
- * Save information of the file, contained into the entries of the user interface, in the list.
- * An undo key is generated to be used for filename and tag if there are changed is the same time.
- * Filename and Tag.
- */
-void ET_Save_File_Data_From_UI (ET_File *ETFile)
-{
-    const ET_File_Description *description;
-    File_Name *FileName;
-    File_Tag  *FileTag;
-    guint      undo_key;
-    const gchar *cur_filename_utf8;
-
-    g_return_if_fail (ETFile != NULL && ETFile->FileNameCur != NULL
-                      && ETFile->FileNameCur->data != NULL);
-
-    cur_filename_utf8 = ((File_Name *)((GList *)ETFile->FileNameCur)->data)->value_utf8;
-    description = ETFile->ETFileDescription;
-    undo_key = ET_Undo_Key_New();
-
-
-    /*
-     * Save filename and generate undo for filename
-     */
-    FileName = g_slice_new (File_Name);
-    ET_Initialize_File_Name_Item (FileName);
-    FileName->key = undo_key;
-    ET_Save_File_Name_From_UI(ETFile,FileName); // Used for all files!
-
-    switch (description->TagType)
-    {
-#ifdef ENABLE_MP3
-        case ID3_TAG:
-#endif
-#ifdef ENABLE_OGG
-        case OGG_TAG:
-#endif
-#ifdef ENABLE_FLAC
-        case FLAC_TAG:
-#endif
-#ifdef ENABLE_MP4
-        case MP4_TAG:
-#endif
-#ifdef ENABLE_WAVPACK
-        case WAVPACK_TAG:
-#endif
-#ifdef ENABLE_OPUS
-        case OPUS_TAG:
-#endif
-        case APE_TAG:
-            FileTag = et_application_window_tag_area_create_file_tag (ET_APPLICATION_WINDOW (MainWindow));
-            et_file_tag_copy_other_into (ETFile->FileTag->data, FileTag);
-            break;
-        case UNKNOWN_TAG:
-        default:
-            FileTag = et_file_tag_new ();
-            Log_Print (LOG_ERROR,
-                       "FileTag: Undefined tag type %d for file %s.",
-                       description->TagType, cur_filename_utf8);
-            break;
-    }
-
-    /*
-     * Generate undo for the file and the main undo list.
-     * If no changes detected, FileName and FileTag item are deleted.
-     */
-    ET_Manage_Changes_Of_File_Data(ETFile,FileName,FileTag);
-
-    /* Refresh file into browser list */
-    et_application_window_browser_refresh_file_in_list (ET_APPLICATION_WINDOW (MainWindow),
-                                                        ETFile);
-}
-
-
-/*
- * Save displayed filename into list if it had been changed. Generates also an history list for undo/redo.
- *  - ETFile : the current etfile that we want to save,
- *  - FileName : where is 'temporary' saved the new filename.
- *
- * Note : it builds new filename (with path) from strings encoded into file system
- *        encoding, not UTF-8 (it preserves file system encoding of parent directories).
- */
-static gboolean
-ET_Save_File_Name_From_UI (const ET_File *ETFile, File_Name *FileName)
-{
-    gchar *filename_new = NULL;
-    gchar *dirname = NULL;
-    gchar *filename;
-    const gchar *filename_utf8;
-    gchar *extension;
-
-    g_return_val_if_fail (ETFile != NULL && FileName != NULL, FALSE);
-
-    filename_utf8 = et_application_window_file_area_get_filename (ET_APPLICATION_WINDOW (MainWindow));
-    filename = filename_from_display (filename_utf8);
-
-    if (!filename)
-    {
-        // If translation fails...
-        GtkWidget *msgdialog;
-        gchar *filename_escaped_utf8 = g_strescape(filename_utf8, NULL);
-        msgdialog = gtk_message_dialog_new(GTK_WINDOW(MainWindow),
-                                           GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                           GTK_MESSAGE_ERROR,
-                                           GTK_BUTTONS_CLOSE,
-                                           _("Could not convert filename ‘%s’ to system filename encoding"),
-                                           filename_escaped_utf8);
-        gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(msgdialog),_("Try setting the environment variable G_FILENAME_ENCODING."));
-        gtk_window_set_title(GTK_WINDOW(msgdialog), _("Filename translation"));
-
-        gtk_dialog_run(GTK_DIALOG(msgdialog));
-        gtk_widget_destroy(msgdialog);
-        g_free(filename_escaped_utf8);
-        return FALSE;
-    }
-
-    // Get the current path to the file
-    dirname = g_path_get_dirname( ((File_Name *)ETFile->FileNameNew->data)->value );
-
-    // Convert filename extension (lower or upper)
-    extension = ET_File_Name_Format_Extension(ETFile);
-
-    // Check length of filename (limit ~255 characters)
-    //ET_File_Name_Check_Length(ETFile,filename);
-
-    // Filename (in file system encoding!)
-    if (filename && strlen(filename)>0)
-    {
-        // Regenerate the new filename (without path)
-        filename_new = g_strconcat(filename,extension,NULL);
-    }else
-    {
-        // Keep the 'last' filename (if a 'blank' filename was entered in the fileentry for ex)...
-        filename_new = g_path_get_basename( ((File_Name *)ETFile->FileNameNew->data)->value );
-    }
-    g_free (filename);
-    g_free (extension);
-
-    // Check if new filename seems to be correct
-    if ( !filename_new || strlen(filename_new) <= strlen(ETFile->ETFileDescription->Extension) )
-    {
-        FileName->value      = NULL;
-        FileName->value_utf8 = NULL;
-        FileName->value_ck   = NULL;
-
-        g_free(filename_new);
-        g_free(dirname);
-        return FALSE;
-    }
-
-    // Convert the illegal characters
-    ET_File_Name_Convert_Character(filename_new); // FIX ME : should be in UTF8?
-
-    /* Set the new filename (in file system encoding). */
-    FileName->value = g_strconcat(dirname,G_DIR_SEPARATOR_S,filename_new,NULL);
-    /* Set the new filename (in UTF-8 encoding). */
-    FileName->value_utf8 = filename_to_display(FileName->value);
-    // Calculates collate key
-    FileName->value_ck = g_utf8_collate_key_for_filename(FileName->value_utf8, -1);
-
-    g_free(filename_new);
-    g_free(dirname);
-    return TRUE;
-}
-
-
 /*
  * Do the same thing of ET_Save_File_Name_From_UI, but without getting the
  * data from the UI.
@@ -1571,6 +1054,7 @@ ET_Save_File_Name_Internal (const ET_File *ETFile,
     gchar *filename;
     gchar *extension;
     gchar *pos;
+    gboolean success;
 
     g_return_val_if_fail (ETFile != NULL && FileName != NULL, FALSE);
 
@@ -1584,8 +1068,8 @@ ET_Save_File_Name_Internal (const ET_File *ETFile,
     if ((pos=strrchr(filename, '.'))!=NULL)
         *pos = 0;
 
-    // Convert filename extension (lower/upper)
-    extension = ET_File_Name_Format_Extension(ETFile);
+    /* Convert filename extension (lower/upper). */
+    extension = ET_File_Format_File_Extension (ETFile);
 
     // Check length of filename
     //ET_File_Name_Check_Length(ETFile,filename);
@@ -1595,32 +1079,14 @@ ET_Save_File_Name_Internal (const ET_File *ETFile,
     g_free(extension);
     g_free(filename);
 
-    // Check if new filename seems to be correct
-    if (filename_new)
-    {
-        // Convert the illegal characters
-        ET_File_Name_Convert_Character(filename_new);
+    success = et_file_name_set_from_components (FileName, filename_new,
+                                                dirname,
+                                                g_settings_get_boolean (MainSettings,
+                                                                        "rename-replace-illegal-chars"));
 
-        /* Set the new filename (in file system encoding). */
-        FileName->value = g_strconcat(dirname,G_DIR_SEPARATOR_S,filename_new,NULL);
-        /* Set the new filename (in UTF-8 encoding). */
-        FileName->value_utf8 = filename_to_display(FileName->value);
-        // Calculate collate key
-        FileName->value_ck = g_utf8_collate_key_for_filename(FileName->value_utf8, -1);
-
-        g_free(filename_new);
-        g_free(dirname);
-        return TRUE;
-    }else
-    {
-        FileName->value = NULL;
-        FileName->value_utf8 = NULL;
-        FileName->value_ck = NULL;
-
-        g_free(filename_new);
-        g_free(dirname);
-        return FALSE;
-    }
+    g_free (filename_new);
+    g_free (dirname);
+    return success;
 }
 
 /*
@@ -1638,7 +1104,7 @@ ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag)
     FileTagCur = (File_Tag *)ETFile->FileTag->data;
 
     /* Title */
-    if ( FileTagCur->title && g_utf8_strlen(FileTagCur->title, -1)>0 )
+    if (!et_str_empty (FileTagCur->title))
     {
         FileTag->title = g_strdup(FileTagCur->title);
         g_strstrip (FileTag->title);
@@ -1648,7 +1114,7 @@ ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag)
     }
 
     /* Artist */
-    if ( FileTagCur->artist && g_utf8_strlen(FileTagCur->artist, -1)>0 )
+    if (!et_str_empty (FileTagCur->artist))
     {
         FileTag->artist = g_strdup(FileTagCur->artist);
         g_strstrip (FileTag->artist);
@@ -1657,8 +1123,8 @@ ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag)
         FileTag->artist = NULL;
     }
 
-	/* Album Artist */
-    if ( FileTagCur->album_artist && g_utf8_strlen(FileTagCur->album_artist, -1)>0 )
+    /* Album Artist */
+    if (!et_str_empty (FileTagCur->album_artist))
     {
         FileTag->album_artist = g_strdup(FileTagCur->album_artist);
         g_strstrip (FileTag->album_artist);
@@ -1669,7 +1135,7 @@ ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag)
 
 
     /* Album */
-    if ( FileTagCur->album && g_utf8_strlen(FileTagCur->album, -1)>0 )
+    if (!et_str_empty (FileTagCur->album))
     {
         FileTag->album = g_strdup(FileTagCur->album);
         g_strstrip (FileTag->album);
@@ -1680,7 +1146,7 @@ ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag)
 
 
     /* Disc Number */
-    if ( FileTagCur->disc_number && g_utf8_strlen(FileTagCur->disc_number, -1)>0 )
+    if (!et_str_empty (FileTagCur->disc_number))
     {
         FileTag->disc_number = g_strdup(FileTagCur->disc_number);
         g_strstrip (FileTag->disc_number);
@@ -1691,8 +1157,7 @@ ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag)
 
 
     /* Discs Total */
-    if (FileTagCur->disc_total
-        && g_utf8_strlen (FileTagCur->disc_total, -1) > 0)
+    if (!et_str_empty (FileTagCur->disc_total))
     {
         FileTag->disc_total = et_disc_number_to_string (atoi (FileTagCur->disc_total));
         g_strstrip (FileTag->disc_total);
@@ -1704,7 +1169,7 @@ ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag)
 
 
     /* Year */
-    if ( FileTagCur->year && g_utf8_strlen(FileTagCur->year, -1)>0 )
+    if (!et_str_empty (FileTagCur->year))
     {
         FileTag->year = g_strdup(FileTagCur->year);
         g_strstrip (FileTag->year);
@@ -1715,7 +1180,7 @@ ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag)
 
 
     /* Track */
-    if ( FileTagCur->track && g_utf8_strlen(FileTagCur->track, -1)>0 )
+    if (!et_str_empty (FileTagCur->track))
     {
         gchar *tmp_str;
 
@@ -1733,7 +1198,7 @@ ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag)
 
 
     /* Track Total */
-    if ( FileTagCur->track_total && g_utf8_strlen(FileTagCur->track_total, -1)>0 )
+    if (!et_str_empty (FileTagCur->track_total))
     {
         FileTag->track_total = et_track_number_to_string (atoi (FileTagCur->track_total));
         g_strstrip (FileTag->track_total);
@@ -1744,7 +1209,7 @@ ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag)
 
 
     /* Genre */
-    if ( FileTagCur->genre && g_utf8_strlen(FileTagCur->genre, -1)>0 )
+    if (!et_str_empty (FileTagCur->genre))
     {
         FileTag->genre = g_strdup(FileTagCur->genre);
         g_strstrip (FileTag->genre);
@@ -1755,7 +1220,7 @@ ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag)
 
 
     /* Comment */
-    if ( FileTagCur->comment && g_utf8_strlen(FileTagCur->comment, -1)>0 )
+    if (!et_str_empty (FileTagCur->comment))
     {
         FileTag->comment = g_strdup(FileTagCur->comment);
         g_strstrip (FileTag->comment);
@@ -1766,7 +1231,7 @@ ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag)
 
 
     /* Composer */
-    if ( FileTagCur->composer && g_utf8_strlen(FileTagCur->composer, -1)>0 )
+    if (!et_str_empty (FileTagCur->composer))
     {
         FileTag->composer = g_strdup(FileTagCur->composer);
         g_strstrip (FileTag->composer);
@@ -1777,7 +1242,7 @@ ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag)
 
 
     /* Original Artist */
-    if ( FileTagCur->orig_artist && g_utf8_strlen(FileTagCur->orig_artist, -1)>0 )
+    if (!et_str_empty (FileTagCur->orig_artist))
     {
         FileTag->orig_artist = g_strdup(FileTagCur->orig_artist);
         g_strstrip (FileTag->orig_artist);
@@ -1788,7 +1253,7 @@ ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag)
 
 
     /* Copyright */
-    if ( FileTagCur->copyright && g_utf8_strlen(FileTagCur->copyright, -1)>0 )
+    if (!et_str_empty (FileTagCur->copyright))
     {
         FileTag->copyright = g_strdup(FileTagCur->copyright);
         g_strstrip (FileTag->copyright);
@@ -1799,7 +1264,7 @@ ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag)
 
 
     /* URL */
-    if ( FileTagCur->url && g_utf8_strlen(FileTagCur->url, -1)>0 )
+    if (!et_str_empty (FileTagCur->url))
     {
         FileTag->url = g_strdup(FileTagCur->url);
         g_strstrip (FileTag->url);
@@ -1810,7 +1275,7 @@ ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag)
 
 
     /* Encoded by */
-    if ( FileTagCur->encoded_by && g_utf8_strlen(FileTagCur->encoded_by, -1)>0 )
+    if (!et_str_empty (FileTagCur->encoded_by))
     {
         FileTag->encoded_by = g_strdup(FileTagCur->encoded_by);
         g_strstrip (FileTag->encoded_by);
@@ -1892,7 +1357,7 @@ ET_Save_File_Tag_To_HD (ET_File *ETFile, GError **error)
         default:
             Log_Print (LOG_ERROR,
                        "Saving to HD: Undefined function for tag type '%d' (file %s).",
-                       description->TagType, cur_filename_utf8);
+                       (gint)description->TagType, cur_filename_utf8);
             state = FALSE;
             break;
     }
@@ -1971,13 +1436,15 @@ ET_Manage_Changes_Of_File_Data (ET_File *ETFile,
      */
     if (FileName)
     {
-        if ( ETFile->FileNameNew && ET_Detect_Changes_Of_File_Name( (File_Name *)(ETFile->FileNameNew)->data,FileName )==TRUE )
+        if (ETFile->FileNameNew
+            && et_file_name_detect_difference ((File_Name *)(ETFile->FileNameNew)->data,
+                                               FileName) == TRUE)
         {
             ET_Add_File_Name_To_List(ETFile,FileName);
             undo_added |= TRUE;
         }else
         {
-            ET_Free_File_Name_Item(FileName);
+            et_file_name_free (FileName);
         }
     }
 
@@ -2012,43 +1479,6 @@ ET_Manage_Changes_Of_File_Data (ET_File *ETFile,
     return undo_added;
 }
 
-/*
- * Compares two File_Name items :
- *  - returns TRUE if there aren't the same
- *  - else returns FALSE
- */
-static gboolean
-ET_Detect_Changes_Of_File_Name (const File_Name *FileName1,
-                                const File_Name *FileName2)
-{
-    const gchar *filename1_ck;
-    const gchar *filename2_ck;
-
-    if (!FileName1 && !FileName2) return FALSE;
-    if (FileName1 && !FileName2) return TRUE;
-    if (!FileName1 && FileName2) return TRUE;
-
-    /* Both FileName1 and FileName2 are != NULL. */
-    if (!FileName1->value && !FileName2->value) return FALSE;
-    if (FileName1->value && !FileName2->value) return TRUE;
-    if (!FileName1->value && FileName2->value) return TRUE;
-
-    /* Compare collate keys (with FileName->value converted to UTF-8 as it
-     * contains raw data). */
-    filename1_ck = FileName1->value_ck;
-    filename2_ck = FileName2->value_ck;
-
-    /* Filename changed ? (we check path + file). */
-    if (strcmp (filename1_ck, filename2_ck) != 0)
-    {
-        return TRUE;
-    }
-    else
-    {
-        return FALSE;
-    }
-}
-
 /*
  * Add a FileName item to the history list of ETFile
  */
@@ -2322,8 +1752,8 @@ ET_File_Name_Generate (const ET_File *ETFile,
         gchar *extension;
         gchar *new_file_name_path_utf8;
 
-        // Convert filename extension (lower/upper)
-        extension = ET_File_Name_Format_Extension(ETFile);
+        /* Convert filename extension (lower/upper). */
+        extension = ET_File_Format_File_Extension (ETFile);
 
         // Check length of filename (limit ~255 characters)
         //ET_File_Name_Check_Length(ETFile,new_file_name_utf8);
@@ -2366,8 +1796,8 @@ gchar *ET_File_Name_Generate (ET_File *ETFile, gchar *new_file_name_utf8)
 
         new_file_name = filename_from_display(new_file_name_utf8);
 
-        // Convert filename extension (lower/upper)
-        extension = ET_File_Name_Format_Extension(ETFile);
+        /* Convert filename extension (lower/upper). */
+        extension = ET_File_Format_File_Extension (ETFile);
 
         // Check length of filename (limit ~255 characters)
         //ET_File_Name_Check_Length(ETFile,new_file_name_utf8);
@@ -2399,8 +1829,8 @@ gchar *ET_File_Name_Generate (ET_File *ETFile, gchar *new_file_name_utf8)
 
 
 /* Convert filename extension (lower/upper/no change). */
-static gchar *
-ET_File_Name_Format_Extension (const ET_File *ETFile)
+gchar *
+ET_File_Format_File_Extension (const ET_File *ETFile)
 {
     EtFilenameExtensionMode mode;
 
@@ -2418,54 +1848,3 @@ ET_File_Name_Format_Extension (const ET_File *ETFile)
             return g_strdup (ETFile->ETFileExtension);
     };
 }
-
-
-/*
- * Used to replace the illegal characters in the filename
- * Paremeter 'filename' musn't contain the path, else directories separators would be replaced!
- */
-gboolean ET_File_Name_Convert_Character (gchar *filename_utf8)
-{
-    gchar *character;
-
-    g_return_val_if_fail (filename_utf8 != NULL, FALSE);
-
-    // Convert automatically the directory separator ('/' on LINUX and '\' on WIN32) to '-'.
-    while ( (character=g_utf8_strchr(filename_utf8, -1, G_DIR_SEPARATOR))!=NULL )
-        *character = '-';
-
-#ifdef G_OS_WIN32
-    /* Convert character '\' on WIN32 to '-'. */
-    while ( (character=g_utf8_strchr(filename_utf8, -1, '\\'))!=NULL )
-        *character = '-';
-    /* Convert character '/' on WIN32 to '-'. May be converted to '\' after. */
-    while ( (character=g_utf8_strchr(filename_utf8, -1, '/'))!=NULL )
-        *character = '-';
-#endif /* G_OS_WIN32 */
-
-    /* Convert other illegal characters on FAT32/16 filesystems and ISO9660 and
-     * Joliet (CD-ROM filesystems). */
-    if (g_settings_get_boolean (MainSettings, "rename-replace-illegal-chars"))
-    {
-        // Commented as we display unicode values as "\351" for "é"
-        //while ( (character=g_utf8_strchr(filename_utf8, -1, '\\'))!=NULL )
-        //    *character = ',';
-        while ( (character=g_utf8_strchr(filename_utf8, -1, ':'))!=NULL )
-            *character = '-';
-        //while ( (character=g_utf8_strchr(filename_utf8, -1, ';'))!=NULL )
-        //    *character = '-';
-        while ( (character=g_utf8_strchr(filename_utf8, -1, '*'))!=NULL )
-            *character = '+';
-        while ( (character=g_utf8_strchr(filename_utf8, -1, '?'))!=NULL )
-            *character = '_';
-        while ( (character=g_utf8_strchr(filename_utf8, -1, '\"'))!=NULL )
-            *character = '\'';
-        while ( (character=g_utf8_strchr(filename_utf8, -1, '<'))!=NULL )
-            *character = '(';
-        while ( (character=g_utf8_strchr(filename_utf8, -1, '>'))!=NULL )
-            *character = ')';
-        while ( (character=g_utf8_strchr(filename_utf8, -1, '|'))!=NULL )
-            *character = '-';
-    }
-    return TRUE;
-}
