@@ -32,6 +32,7 @@
 #include "charset.h"
 #include "easytag.h"
 #include "log.h"
+#include "misc.h"
 #include "mpeg_header.h"
 #include "monkeyaudio_header.h"
 #include "musepack_header.h"
@@ -89,7 +90,10 @@ et_history_file_list_free (GList *file_list)
 {
     g_return_if_fail (file_list != NULL);
 
-    g_list_free_full (file_list, (GDestroyNotify)et_history_file_free);
+    /* et_history_list_add() sets the list to the final element, so explicitly
+     * go back to the start. */
+    g_list_free_full (g_list_first (file_list),
+                      (GDestroyNotify)et_history_file_free);
 }
 
 /*
@@ -224,11 +228,9 @@ et_file_list_add (GList *file_list,
     ETFileExtension = g_strdup(ET_Get_File_Extension(filename));
 
     /* Fill the File_Name structure for FileNameList */
-    FileName = ET_File_Name_Item_New();
+    FileName = et_file_name_new ();
     FileName->saved      = TRUE;    /* The file hasn't been changed, so it's saved */
-    FileName->value      = filename;
-    FileName->value_utf8 = filename_utf8;
-    FileName->value_ck   = g_utf8_collate_key_for_filename(filename_utf8, -1);
+    ET_Set_Filename_File_Name_Item (FileName, filename_utf8, filename);
 
     /* Fill the File_Tag structure for FileTagList */
     FileTag = et_file_tag_new ();
@@ -247,7 +249,7 @@ et_file_list_add (GList *file_list,
             if (!id3tag_read_file_tag (file, FileTag, &error))
             {
                 Log_Print (LOG_ERROR,
-                           "Error reading ID3 tag from file ‘%s’: %s",
+                           _("Error reading ID3 tag from file ‘%s’: %s"),
                            filename_utf8, error->message);
                 g_clear_error (&error);
             }
@@ -322,7 +324,7 @@ et_file_list_add (GList *file_list,
             /* FIXME: Translatable string. */
             Log_Print (LOG_ERROR,
                        "FileTag: Undefined tag type (%d) for file %s",
-                       description->TagType, filename_utf8);
+                       (gint)description->TagType, filename_utf8);
             break;
     }
 
@@ -334,7 +336,7 @@ et_file_list_add (GList *file_list,
     }
 
     /* Fill the ET_File_Info structure */
-    ETFileInfo = ET_File_Info_Item_New ();
+    ETFileInfo = et_file_info_new ();
 
     switch (description->FileType)
     {
@@ -388,7 +390,7 @@ et_file_list_add (GList *file_list,
             /* FIXME: Translatable string. */
             Log_Print (LOG_ERROR,
                        "ETFileInfo: Undefined file type (%d) for file %s",
-                       description->FileType, filename_utf8);
+                       (gint)description->FileType, filename_utf8);
             /* To get at least the file size. */
             success = et_core_read_file_info (file, ETFileInfo, &error);
             break;
@@ -444,9 +446,9 @@ et_file_list_add (GList *file_list,
      * Process the filename and tag to generate undo if needed...
      * The undo key must be the same for FileName and FileTag => changed in the same time
      */
-    undo_key = ET_Undo_Key_New();
+    undo_key = et_undo_key_new ();
 
-    FileName = ET_File_Name_Item_New();
+    FileName = et_file_name_new ();
     FileName->key = undo_key;
     ET_Save_File_Name_Internal(ETFile,FileName);
 
@@ -475,6 +477,9 @@ et_file_list_add (GList *file_list,
     //ET_Add_File_To_Artist_Album_File_List(ETFile);
 
     //ET_Debug_Print_File_List(ETCore->ETFileList,__FILE__,__LINE__,__FUNCTION__);
+
+    g_free (filename_utf8);
+
     return result;
 }
 
@@ -574,7 +579,7 @@ et_artist_album_list_add_file (GList *file_list,
     GList *result;
     ET_File *etfile = NULL;
 
-    g_return_if_fail (ETFile != NULL);
+    g_return_val_if_fail (ETFile != NULL, NULL);
 
     /* Album value of the ETFile passed in parameter. */
     ETFile_Album = ((File_Tag *)ETFile->FileTag->data)->album;
@@ -1129,15 +1134,6 @@ ET_Displayed_File_List_By_Etfile (const ET_File *ETFile)
     return etfilelist;
 }
 
-/*
- * Just returns the current item of the "main list"
- */
-/*GList *ET_Displayed_File_List_Current (void)
-{
-    return ETCore->ETFileDisplayedList;
-    //return ETCore->ETFileDisplayedListPtr;
-}*/
-
 /*
  * Load the list of displayed files (calculate length, size, ...)
  * It contains part (filtrated : view by artists and albums) or full ETCore->ETFileList list
@@ -1222,15 +1218,9 @@ et_file_list_update_directory_name (GList *file_list,
                                                     (new_path[strlen (new_path) - 1] == G_DIR_SEPARATOR) ? "" : G_DIR_SEPARATOR_S,
                                                     &filename[strlen (old_path_tmp)],NULL);
 
-                        /* Replace the filename (in file system encoding). */
-                        g_free (FileName->value);
-                        FileName->value = filename_tmp;
-                        /* Replace the filename (in file system encoding). */
-                        g_free (FileName->value_utf8);
-                        FileName->value_utf8 = filename_to_display (FileName->value);
-                        /* Recalculate the collate key. */
-                        g_free (FileName->value_ck);
-                        FileName->value_ck = g_utf8_collate_key_for_filename (FileName->value_utf8, -1);
+                        ET_Set_Filename_File_Name_Item (FileName, NULL,
+                                                        filename_tmp);
+                        g_free (filename_tmp);
                     }
                 }
              }
