@@ -91,8 +91,7 @@ Load_Filename_Set_Filenames (EtLoadFilesDialog *self)
     if ( !ETCore->ETFileList || !priv->load_file_content_view || !priv->load_file_name_view)
         return;
 
-    /* Save current file */
-    ET_Save_File_Data_From_UI(ETCore->ETFileDisplayed);
+    et_application_window_update_et_file_from_ui (ET_APPLICATION_WINDOW (MainWindow));
 
     rowcount = MIN(gtk_tree_model_iter_n_children(GTK_TREE_MODEL(priv->load_file_name_model), NULL),
                    gtk_tree_model_iter_n_children(GTK_TREE_MODEL(priv->load_file_content_model), NULL));
@@ -114,13 +113,15 @@ Load_Filename_Set_Filenames (EtLoadFilesDialog *self)
             gtk_tree_model_get(GTK_TREE_MODEL(priv->load_file_content_model), &iter_content, 
                                LOAD_FILE_CONTENT_TEXT, &list_text, -1);
 
-        if (ETFile && list_text && (g_utf8_strlen (list_text, -1) > 0))
+        if (ETFile && !et_str_empty (list_text))
         {
             gchar *list_text_tmp;
             gchar *filename_new_utf8;
 
             list_text_tmp = g_strdup(list_text);
-            ET_File_Name_Convert_Character(list_text_tmp); // Replace invalid characters
+            et_filename_prepare (list_text_tmp,
+                                 g_settings_get_boolean (MainSettings,
+                                                         "rename-replace-illegal-chars"));
 
             /* Build the filename with the path */
             filename_new_utf8 = ET_File_Name_Generate(ETFile,list_text_tmp);
@@ -128,7 +129,7 @@ Load_Filename_Set_Filenames (EtLoadFilesDialog *self)
 
             /* Set the new filename */
             // Create a new 'File_Name' item
-            FileName = ET_File_Name_Item_New();
+            FileName = et_file_name_new ();
             // Save changes of the 'File_Name' item
             ET_Set_Filename_File_Name_Item(FileName,filename_new_utf8,NULL);
             ET_Manage_Changes_Of_File_Data(ETFile,FileName,NULL);
@@ -155,7 +156,8 @@ Load_Filename_Set_Filenames (EtLoadFilesDialog *self)
     gtk_tree_path_free(currentPath);
 
     et_application_window_browser_refresh_list (ET_APPLICATION_WINDOW (MainWindow));
-    ET_Display_File_Data_To_UI(ETCore->ETFileDisplayed);
+    et_application_window_display_et_file (ET_APPLICATION_WINDOW (MainWindow),
+                                           ETCore->ETFileDisplayed);
 }
 
 /*
@@ -396,7 +398,7 @@ Load_Filename_List_Delete_All_Blank_Lines (GtkWidget *treeview)
         gtk_tree_model_get(model, &iter, LOAD_FILE_NAME_TEXT, &text, -1);
 
         /* Check for blank entry */
-        if (!text || g_utf8_strlen(text, -1) == 0)
+        if (et_str_empty (text))
         {
             g_free(text);
 
@@ -1074,12 +1076,6 @@ create_load_files_dialog (EtLoadFilesDialog *self)
     g_signal_emit_by_name (G_OBJECT (priv->file_chooser), "file-set");
 }
 
-static void
-et_load_files_dialog_finalize (GObject *object)
-{
-    G_OBJECT_CLASS (et_load_files_dialog_parent_class)->finalize (object);
-}
-
 static void
 et_load_files_dialog_init (EtLoadFilesDialog *self)
 {
@@ -1092,8 +1088,6 @@ et_load_files_dialog_init (EtLoadFilesDialog *self)
 static void
 et_load_files_dialog_class_init (EtLoadFilesDialogClass *klass)
 {
-    G_OBJECT_CLASS (klass)->finalize = et_load_files_dialog_finalize;
-
     g_type_class_add_private (klass, sizeof (EtLoadFilesDialogPrivate));
 }
 
