@@ -34,11 +34,6 @@
 #endif /* G_OS_WIN32 */
 
 
-/***************
- * Declaration *
- ***************/
-static const guint BOX_SPACING = 6;
-
 /*
  * Add the 'string' passed in parameter to the list store
  * If this string already exists in the list store, it doesn't add it.
@@ -52,7 +47,7 @@ gboolean Add_String_To_Combo_List (GtkListStore *liststore, const gchar *str)
     //gboolean found = FALSE;
     gchar *string = g_strdup(str);
 
-    if (!string || g_utf8_strlen(string, -1) <= 0)
+    if (et_str_empty (string))
     {
         g_free (string);
         return FALSE;
@@ -324,16 +319,22 @@ gchar *Convert_Duration (gulong duration)
     gchar *data = NULL;
 
     if (duration == 0)
-        return g_strdup_printf("%d:%.2d",minute,second);
+    {
+        return g_strdup_printf ("%u:%.2u", minute, second);
+    }
 
     hour   = duration/3600;
     minute = (duration%3600)/60;
     second = (duration%3600)%60;
 
     if (hour)
-        data = g_strdup_printf("%d:%.2d:%.2d",hour,minute,second);
+    {
+        data = g_strdup_printf ("%u:%.2u:%.2u", hour, minute, second);
+    }
     else
-        data = g_strdup_printf("%d:%.2d",minute,second);
+    {
+        data = g_strdup_printf ("%u:%.2u", minute, second);
+    }
 
     return data;
 }
@@ -343,13 +344,13 @@ et_disc_number_to_string (const guint disc_number)
 {
     if (g_settings_get_boolean (MainSettings, "tag-disc-padded"))
     {
-        return g_strdup_printf ("%.*d",
-                                g_settings_get_uint (MainSettings,
-                                                     "tag-disc-length"),
+        return g_strdup_printf ("%.*u",
+                                (gint)g_settings_get_uint (MainSettings,
+                                                           "tag-disc-length"),
                                 disc_number);
     }
 
-    return g_strdup_printf ("%d", disc_number);
+    return g_strdup_printf ("%u", disc_number);
 }
 
 gchar *
@@ -357,12 +358,130 @@ et_track_number_to_string (const guint track_number)
 {
     if (g_settings_get_boolean (MainSettings, "tag-number-padded"))
     {
-        return g_strdup_printf ("%.*d", g_settings_get_uint (MainSettings,
-                                                             "tag-number-length"),
+        return g_strdup_printf ("%.*u",
+                                (gint)g_settings_get_uint (MainSettings,
+                                                           "tag-number-length"),
                                 track_number);
     }
     else
     {
-        return g_strdup_printf ("%d", track_number);
+        return g_strdup_printf ("%u", track_number);
     }
 }
+
+/*
+ * et_filename_prepare:
+ * @filename_utf8: UTF8-encoded basename
+ * @replace_illegal: whether to replace illegal characters in the file name
+ *
+ * Used to replace (in place) the illegal characters in the filename.
+ */
+void
+et_filename_prepare (gchar *filename_utf8,
+                     gboolean replace_illegal)
+{
+    gchar *character;
+
+    g_return_if_fail (filename_utf8 != NULL);
+
+    // Convert automatically the directory separator ('/' on LINUX and '\' on WIN32) to '-'.
+    while ( (character=g_utf8_strchr(filename_utf8, -1, G_DIR_SEPARATOR))!=NULL )
+        *character = '-';
+
+#ifdef G_OS_WIN32
+    /* Convert character '\' on WIN32 to '-'. */
+    while ( (character=g_utf8_strchr(filename_utf8, -1, '\\'))!=NULL )
+        *character = '-';
+    /* Convert character '/' on WIN32 to '-'. May be converted to '\' after. */
+    while ( (character=g_utf8_strchr(filename_utf8, -1, '/'))!=NULL )
+        *character = '-';
+#endif /* G_OS_WIN32 */
+
+    /* Convert other illegal characters on FAT32/16 filesystems and ISO9660 and
+     * Joliet (CD-ROM filesystems). */
+    if (replace_illegal)
+    {
+        // Commented as we display unicode values as "\351" for "é"
+        //while ( (character=g_utf8_strchr(filename_utf8, -1, '\\'))!=NULL )
+        //    *character = ',';
+        while ( (character=g_utf8_strchr(filename_utf8, -1, ':'))!=NULL )
+            *character = '-';
+        //while ( (character=g_utf8_strchr(filename_utf8, -1, ';'))!=NULL )
+        //    *character = '-';
+        while ( (character=g_utf8_strchr(filename_utf8, -1, '*'))!=NULL )
+            *character = '+';
+        while ( (character=g_utf8_strchr(filename_utf8, -1, '?'))!=NULL )
+            *character = '_';
+        while ( (character=g_utf8_strchr(filename_utf8, -1, '\"'))!=NULL )
+            *character = '\'';
+        while ( (character=g_utf8_strchr(filename_utf8, -1, '<'))!=NULL )
+            *character = '(';
+        while ( (character=g_utf8_strchr(filename_utf8, -1, '>'))!=NULL )
+            *character = ')';
+        while ( (character=g_utf8_strchr(filename_utf8, -1, '|'))!=NULL )
+            *character = '-';
+    }
+}
+
+/* Key for Undo */
+guint
+et_undo_key_new (void)
+{
+    static guint ETUndoKey = 0;
+    return ++ETUndoKey;
+}
+
+/*
+ * et_normalized_strcmp0:
+ * @str1: UTF-8 string, or %NULL
+ * @str2: UTF-8 string to compare against, or %NULL
+ *
+ * Compare two UTF-8 strings, normalizing them before doing so, and return the
+ * difference.
+ *
+ * Returns: an integer less than, equal to, or greater than zero, if str1 is <,
+ * == or > than str2
+ */
+gint
+et_normalized_strcmp0 (const gchar *str1,
+                       const gchar *str2)
+{
+    gint result;
+    gchar *normalized1;
+    gchar *normalized2;
+
+    /* Check for NULL, as it cannot be passed to g_utf8_normalize(). */
+    if (!str1)
+    {
+        return -(str1 != str2);
+    }
+
+    if (!str2)
+    {
+        return str1 != str2;
+    }
+
+    normalized1 = g_utf8_normalize (str1, -1, G_NORMALIZE_DEFAULT);
+    normalized2 = g_utf8_normalize (str2, -1, G_NORMALIZE_DEFAULT);
+
+    result = g_strcmp0 (normalized1, normalized2);
+
+    g_free (normalized1);
+    g_free (normalized2);
+
+    return result;
+}
+
+/*
+ * et_str_empty:
+ * @str: string to test for emptiness
+ *
+ * Test if @str is empty, in other words either %NULL or the empty string.
+ *
+ * Returns: %TRUE is @str is either %NULL or "", %FALSE otherwise
+ */
+gboolean
+et_str_empty (const gchar *str)
+{
+    return !str || !str[0];
+}
