@@ -225,6 +225,8 @@ write_playlist (EtPlaylistDialog *self, GFile *file, GError **error)
                         g_string_free (to_write, TRUE);
                         g_free (mask);
                         g_free (filename_generated_utf8);
+
+                        break;
                     }
                     default:
                         g_assert_not_reached ();
@@ -427,7 +429,7 @@ write_button_clicked (EtPlaylistDialog *self)
 
     /* Check if playlist name was filled. */
     if (g_settings_get_boolean (MainSettings, "playlist-use-mask")
-        && g_utf8_strlen (gtk_entry_get_text (GTK_ENTRY(priv->name_mask_entry)), -1) <=0)
+        && *(gtk_entry_get_text (GTK_ENTRY (priv->name_mask_entry))) == '\0')
     {
         /* TODO: Can this happen? */
         g_settings_set_boolean (MainSettings, "playlist-use-mask", FALSE);
@@ -602,7 +604,8 @@ entry_check_content_mask (GtkEntry *entry, gpointer user_data)
     g_return_if_fail (entry != NULL);
 
     mask = g_strdup (gtk_entry_get_text (entry));
-    if (!mask || strlen(mask)<1)
+
+    if (et_str_empty (mask))
         goto Bad_Mask;
 
     while (mask)
@@ -772,12 +775,6 @@ create_playlist_dialog (EtPlaylistDialog *self)
     g_signal_emit_by_name (priv->content_mask_entry, "changed");
 }
 
-static void
-et_playlist_dialog_finalize (GObject *object)
-{
-    G_OBJECT_CLASS (et_playlist_dialog_parent_class)->finalize (object);
-}
-
 static void
 et_playlist_dialog_init (EtPlaylistDialog *self)
 {
@@ -790,8 +787,6 @@ et_playlist_dialog_init (EtPlaylistDialog *self)
 static void
 et_playlist_dialog_class_init (EtPlaylistDialogClass *klass)
 {
-    G_OBJECT_CLASS (klass)->finalize = et_playlist_dialog_finalize;
-
     g_type_class_add_private (klass, sizeof (EtPlaylistDialogPrivate));
 }
 
