@@ -695,12 +695,6 @@ et_search_dialog_apply_changes (EtSearchDialog *self)
     Save_Search_File_List (priv->search_string_model, MISC_COMBO_TEXT);
 }
 
-static void
-et_search_dialog_finalize (GObject *object)
-{
-    G_OBJECT_CLASS (et_search_dialog_parent_class)->finalize (object);
-}
-
 static void
 et_search_dialog_init (EtSearchDialog *self)
 {
@@ -713,8 +707,6 @@ et_search_dialog_init (EtSearchDialog *self)
 static void
 et_search_dialog_class_init (EtSearchDialogClass *klass)
 {
-    G_OBJECT_CLASS (klass)->finalize = et_search_dialog_finalize;
-
     g_type_class_add_private (klass, sizeof (EtSearchDialogPrivate));
 }
 
