@@ -162,7 +162,8 @@ flac_tag_read_file_tag (GFile *file,
                     if (field_value)
                     {
                         field_value++;
-                        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+
+                        if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
                             field_value_tmp = g_strndup(field_value, field_len);
@@ -190,7 +191,8 @@ flac_tag_read_file_tag (GFile *file,
                     if (field_value)
                     {
                         field_value++;
-                        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+
+                        if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
                             field_value_tmp = g_strndup(field_value, field_len);
@@ -218,7 +220,8 @@ flac_tag_read_file_tag (GFile *file,
                     if (field_value)
                     {
                         field_value++;
-                        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+
+                        if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
                             field_value_tmp = g_strndup(field_value, field_len);
@@ -246,7 +249,8 @@ flac_tag_read_file_tag (GFile *file,
                     if (field_value)
                     {
                         field_value++;
-                        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+
+                        if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
                             field_value_tmp = g_strndup(field_value, field_len);
@@ -273,7 +277,8 @@ flac_tag_read_file_tag (GFile *file,
                     if (field_value)
                     {
                         field_value++;
-                        if (field_value && g_utf8_strlen (field_value, -1) > 0)
+
+                        if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
                             field_value_tmp = g_strndup (field_value,
@@ -297,7 +302,8 @@ flac_tag_read_file_tag (GFile *file,
                     if (field_value)
                     {
                         field_value++;
-                        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+
+                        if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
                             field_value_tmp = g_strndup(field_value, field_len);
@@ -330,7 +336,8 @@ flac_tag_read_file_tag (GFile *file,
                     if (field_value)
                     {
                         field_value++;
-                        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+
+                        if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
                             field_value_tmp = g_strndup(field_value, field_len);
@@ -353,7 +360,8 @@ flac_tag_read_file_tag (GFile *file,
                     if (field_value)
                     {
                         field_value++;
-                        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+
+                        if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
                             field_value_tmp = g_strndup(field_value, field_len);
@@ -376,7 +384,8 @@ flac_tag_read_file_tag (GFile *file,
                     if (field_value)
                     {
                         field_value++;
-                        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+
+                        if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
                             field_value_tmp = g_strndup(field_value, field_len);
@@ -409,7 +418,8 @@ flac_tag_read_file_tag (GFile *file,
                     if (field_value)
                     {
                         field_value++;
-                        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+
+                        if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
                             field_value_tmp = g_strndup(field_value, field_len);
@@ -457,7 +467,8 @@ flac_tag_read_file_tag (GFile *file,
                     if (field_value)
                     {
                         field_value++;
-                        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+
+                        if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
                             field_value_tmp = g_strndup(field_value, field_len);
@@ -485,7 +496,8 @@ flac_tag_read_file_tag (GFile *file,
                     if (field_value)
                     {
                         field_value++;
-                        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+
+                        if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
                             field_value_tmp = g_strndup(field_value, field_len);
@@ -513,7 +525,8 @@ flac_tag_read_file_tag (GFile *file,
                     if (field_value)
                     {
                         field_value++;
-                        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+
+                        if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
                             field_value_tmp = g_strndup(field_value, field_len);
@@ -541,7 +554,8 @@ flac_tag_read_file_tag (GFile *file,
                     if (field_value)
                     {
                         field_value++;
-                        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+
+                        if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
                             field_value_tmp = g_strndup(field_value, field_len);
@@ -569,7 +583,8 @@ flac_tag_read_file_tag (GFile *file,
                     if (field_value)
                     {
                         field_value++;
-                        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+
+                        if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
                             field_value_tmp = g_strndup(field_value, field_len);
@@ -597,7 +612,8 @@ flac_tag_read_file_tag (GFile *file,
                     if (field_value)
                     {
                         field_value++;
-                        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+
+                        if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
                             field_value_tmp = g_strndup(field_value, field_len);
@@ -695,9 +711,7 @@ flac_tag_read_file_tag (GFile *file,
       && FileTag->encoded_by  == NULL
       && FileTag->picture     == NULL)
     {
-        gboolean rc;
-
-        rc = id3tag_read_file_tag (file, FileTag, NULL);
+        id3tag_read_file_tag (file, FileTag, NULL);
 
         // If an ID3 tag has been found (and no FLAC tag), we mark the file as
         // unsaved to rewrite a flac tag.
@@ -721,8 +735,6 @@ flac_tag_read_file_tag (GFile *file,
         {
             FileTag->saved = FALSE;
         }
-
-        return rc;
     }
 #endif
 
@@ -1190,7 +1202,7 @@ flac_tag_write_file_tag (const ET_File *ETFile,
     {
         // Delete the ID3 tags (create a dummy ETFile for the Id3tag_... function)
         ET_File   *ETFile_tmp    = ET_File_Item_New();
-        File_Name *FileName_tmp  = ET_File_Name_Item_New();
+        File_Name *FileName_tmp = et_file_name_new ();
         File_Tag  *FileTag_tmp = et_file_tag_new ();
         // Same file...
         FileName_tmp->value      = g_strdup(filename);
