@@ -67,9 +67,6 @@ ID3_C_EXPORT size_t ID3Tag_Link_1         (ID3Tag *id3tag, const char *filename)
 ID3_C_EXPORT size_t ID3Field_GetASCII_1   (const ID3Field *field, char *buffer,      size_t maxChars, size_t itemNum);
 ID3_C_EXPORT size_t ID3Field_GetUNICODE_1 (const ID3Field *field, unicode_t *buffer, size_t maxChars, size_t itemNum);
 
-static gboolean et_id3tag_check_if_file_is_corrupted (GFile *file,
-                                                      GError **error);
-
 static gboolean id3tag_check_if_id3lib_is_buggy (GError **error);
 
 
@@ -196,7 +193,7 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
     /* FIXME: Handle this in the caller instead. */
     /* This is a protection against a bug in id3lib that enters an infinite
      * loop with corrupted MP3 files (files containing only zeroes) */
-    if (et_id3tag_check_if_file_is_corrupted (file, error))
+    if (!et_id3tag_check_if_file_is_valid (file, error))
     {
         GtkWidget *msgdialog;
         gchar *basename;
@@ -246,7 +243,7 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
     while ( (id3_frame = ID3Tag_FindFrameWithID(id3_tag,ID3FID_TITLE)) )
         ID3Tag_RemoveFrame(id3_tag,id3_frame);
 
-    if (FileTag->title && g_utf8_strlen(FileTag->title, -1) > 0)
+    if (!et_str_empty (FileTag->title))
     {
         id3_frame = ID3Frame_NewID(ID3FID_TITLE);
         ID3Tag_AttachFrame(id3_tag,id3_frame);
@@ -260,7 +257,8 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
      **********/
     while ( (id3_frame = ID3Tag_FindFrameWithID(id3_tag,ID3FID_LEADARTIST)) )
         ID3Tag_RemoveFrame(id3_tag,id3_frame);
-    if (FileTag->artist && g_utf8_strlen(FileTag->artist, -1) > 0)
+
+    if (!et_str_empty (FileTag->artist))
     {
         id3_frame = ID3Frame_NewID(ID3FID_LEADARTIST);
         ID3Tag_AttachFrame(id3_tag,id3_frame);
@@ -273,7 +271,8 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
      ***************/
     while ( (id3_frame = ID3Tag_FindFrameWithID(id3_tag,ID3FID_BAND)) )
         ID3Tag_RemoveFrame(id3_tag,id3_frame);
-    if (FileTag->album_artist && g_utf8_strlen(FileTag->album_artist, -1) > 0)
+
+    if (!et_str_empty (FileTag->album_artist))
     {
         id3_frame = ID3Frame_NewID(ID3FID_BAND);
         ID3Tag_AttachFrame(id3_tag,id3_frame);
@@ -286,7 +285,8 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
      *********/
     while ( (id3_frame = ID3Tag_FindFrameWithID(id3_tag,ID3FID_ALBUM)) )
         ID3Tag_RemoveFrame(id3_tag,id3_frame);
-    if (FileTag->album && g_utf8_strlen(FileTag->album, -1) > 0)
+
+    if (!et_str_empty (FileTag->album))
     {
         id3_frame = ID3Frame_NewID(ID3FID_ALBUM);
         ID3Tag_AttachFrame(id3_tag,id3_frame);
@@ -300,7 +300,8 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
      *****************************/
     while ( (id3_frame = ID3Tag_FindFrameWithID(id3_tag,ID3FID_PARTINSET)) )
         ID3Tag_RemoveFrame(id3_tag,id3_frame);
-    if (FileTag->disc_number && g_utf8_strlen(FileTag->disc_number, -1) > 0)
+
+    if (!et_str_empty (FileTag->disc_number))
     {
         id3_frame = ID3Frame_NewID (ID3FID_PARTINSET);
         ID3Tag_AttachFrame (id3_tag, id3_frame);
@@ -316,7 +317,8 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
      ********/
     while ( (id3_frame = ID3Tag_FindFrameWithID(id3_tag,ID3FID_YEAR)) )
         ID3Tag_RemoveFrame(id3_tag,id3_frame);
-    if (FileTag->year && g_utf8_strlen(FileTag->year, -1) > 0)
+
+    if (!et_str_empty (FileTag->year))
     {
         id3_frame = ID3Frame_NewID(ID3FID_YEAR);
         ID3Tag_AttachFrame(id3_tag,id3_frame);
@@ -330,12 +332,13 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
      *************************/
     while ( (id3_frame = ID3Tag_FindFrameWithID(id3_tag,ID3FID_TRACKNUM)) )
         ID3Tag_RemoveFrame(id3_tag,id3_frame);
-    if (FileTag->track && g_utf8_strlen(FileTag->track, -1) > 0)
+
+    if (!et_str_empty (FileTag->track))
     {
         id3_frame = ID3Frame_NewID(ID3FID_TRACKNUM);
         ID3Tag_AttachFrame(id3_tag,id3_frame);
 
-        if ( FileTag->track_total && g_utf8_strlen(FileTag->track_total, -1) > 0)
+        if (!et_str_empty (FileTag->track_total))
             string1 = g_strconcat(FileTag->track,"/",FileTag->track_total,NULL);
         else
             string1 = g_strdup(FileTag->track);
@@ -355,7 +358,8 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
      */
     while ( (id3_frame = ID3Tag_FindFrameWithID(id3_tag,ID3FID_CONTENTTYPE)) )
         ID3Tag_RemoveFrame(id3_tag,id3_frame);
-    if (FileTag->genre && strlen(FileTag->genre)>0 )
+
+    if (!et_str_empty (FileTag->genre))
     {
         gchar *genre_string_tmp;
         guchar genre_value;
@@ -386,7 +390,8 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
      ***********/
     while ( (id3_frame = ID3Tag_FindFrameWithID(id3_tag,ID3FID_COMMENT)) )
         ID3Tag_RemoveFrame(id3_tag,id3_frame);
-    if (FileTag->comment && g_utf8_strlen(FileTag->comment, -1) > 0)
+
+    if (!et_str_empty (FileTag->comment))
     {
         id3_frame = ID3Frame_NewID(ID3FID_COMMENT);
         ID3Tag_AttachFrame(id3_tag,id3_frame);
@@ -404,7 +409,8 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
      ************/
     while ( (id3_frame = ID3Tag_FindFrameWithID(id3_tag,ID3FID_COMPOSER)) )
         ID3Tag_RemoveFrame(id3_tag,id3_frame);
-    if (FileTag->composer && g_utf8_strlen(FileTag->composer, -1) > 0)
+
+    if (!et_str_empty (FileTag->composer))
     {
         id3_frame = ID3Frame_NewID(ID3FID_COMPOSER);
         ID3Tag_AttachFrame(id3_tag,id3_frame);
@@ -418,7 +424,8 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
      *******************/
     while ( (id3_frame = ID3Tag_FindFrameWithID(id3_tag,ID3FID_ORIGARTIST)) )
         ID3Tag_RemoveFrame(id3_tag,id3_frame);
-    if (FileTag->orig_artist && g_utf8_strlen(FileTag->orig_artist, -1) > 0)
+
+    if (!et_str_empty (FileTag->orig_artist))
     {
         id3_frame = ID3Frame_NewID(ID3FID_ORIGARTIST);
         ID3Tag_AttachFrame(id3_tag,id3_frame);
@@ -432,7 +439,8 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
      *************/
     while ( (id3_frame = ID3Tag_FindFrameWithID(id3_tag,ID3FID_COPYRIGHT)) )
         ID3Tag_RemoveFrame(id3_tag,id3_frame);
-    if (FileTag->copyright && g_utf8_strlen(FileTag->copyright, -1) > 0)
+
+    if (!et_str_empty (FileTag->copyright))
     {
         id3_frame = ID3Frame_NewID(ID3FID_COPYRIGHT);
         ID3Tag_AttachFrame(id3_tag,id3_frame);
@@ -446,7 +454,8 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
      *******/
     while ( (id3_frame = ID3Tag_FindFrameWithID(id3_tag,ID3FID_WWWUSER)) )
         ID3Tag_RemoveFrame(id3_tag,id3_frame);
-    if (FileTag->url && g_utf8_strlen(FileTag->url, -1) > 0)
+
+    if (!et_str_empty (FileTag->url))
     {
         id3_frame = ID3Frame_NewID(ID3FID_WWWUSER);
         ID3Tag_AttachFrame(id3_tag,id3_frame);
@@ -460,7 +469,8 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
      **************/
     while ( (id3_frame = ID3Tag_FindFrameWithID(id3_tag,ID3FID_ENCODEDBY)) )
         ID3Tag_RemoveFrame(id3_tag,id3_frame);
-    if (FileTag->encoded_by && g_utf8_strlen(FileTag->encoded_by, -1) > 0)
+
+    if (!et_str_empty (FileTag->encoded_by))
     {
         id3_frame = ID3Frame_NewID(ID3FID_ENCODEDBY);
         ID3Tag_AttachFrame(id3_tag,id3_frame);
@@ -565,7 +575,7 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
     {
         // Delete the APE tag (create a dummy ETFile for the Ape_Tag_... function)
         ET_File   *ETFile_tmp    = ET_File_Item_New();
-        File_Name *FileName_tmp  = ET_File_Name_Item_New();
+        File_Name *FileName_tmp = et_file_name_new ();
         File_Tag  *FileTag_tmp = et_file_tag_new();
         // Same file...
         FileName_tmp->value      = g_strdup(filename);
@@ -1388,13 +1398,13 @@ Id3tag_Rules_For_ISO_Fields (const gchar *string,
  * Some files which contains only zeroes create an infinite loop in id3lib...
  * To generate a file with zeroes : dd if=/dev/zero bs=1M count=6 of=test-corrupted-mp3-zero-contend.mp3
  */
-static gboolean
-et_id3tag_check_if_file_is_corrupted (GFile *file, GError **error)
+gboolean
+et_id3tag_check_if_file_is_valid (GFile *file, GError **error)
 {
     unsigned char tmp[256];
     unsigned char tmp0[256];
     gssize bytes_read;
-    gboolean result = TRUE;
+    gboolean valid = FALSE;
     GFileInputStream *file_istream;
 
     g_return_val_if_fail (file != NULL, FALSE);
@@ -1404,10 +1414,12 @@ et_id3tag_check_if_file_is_corrupted (GFile *file, GError **error)
     if (!file_istream)
     {
         g_assert (error == NULL || *error != NULL);
-        return result;
+        return valid;
     }
 
-    memset(&tmp0,0,256);
+    memset (&tmp0, 0, 256);
+
+    /* Keep reading until EOF. */
     while ((bytes_read = g_input_stream_read (G_INPUT_STREAM (file_istream),
                                               tmp, 256, NULL, error)) != 0)
     {
@@ -1416,20 +1428,28 @@ et_id3tag_check_if_file_is_corrupted (GFile *file, GError **error)
             /* Error in reading file. */
             g_assert (error == NULL || *error != NULL);
             g_object_unref (file_istream);
-            return result;
+            return valid;
         }
 
+        /* Break out of the loop if there is a non-zero byte in the file. */
         if (memcmp (tmp, tmp0, bytes_read) != 0)
         {
-            result = FALSE;
+            valid = TRUE;
             break;
         }
     }
 
-    g_assert (error == NULL || *error == NULL);
     g_object_unref (file_istream);
 
-    return result;
+    /* The error was not set by g_input_stream_read(), so the file must be
+     * empty. */
+    if (!valid)
+    {
+        g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED, "%s",
+                     "Input truncated or empty");
+    }
+
+    return valid;
 }
 
 
